@@ -36,8 +36,8 @@
 
 
 /////////////////////// Qt includes
-#include <QMessageBox>
-
+#include<QMessageBox>
+#include<QFileDialog>
 
 /////////////////////// Local includes
 #include "compositionsDlg.hpp"
@@ -497,10 +497,11 @@ namespace massXpert
   {
     mpa_resultsString->clear();
   
-    *mpa_resultsString += QObject::tr("\n-------------\n"
-				       "Compositions: \n"
-				       "-------------\n");
-
+    *mpa_resultsString += QObject::tr("# \n"
+                                      "# -------------\n"
+                                      "# Compositions: \n"
+                                      "# -------------\n");
+    
     if (target == MXP_TARGET_ELEMENTAL)
       {
 	*mpa_resultsString += QObject::tr("\nIonization rule:\n");
