@@ -36,13 +36,15 @@
 
 
 /////////////////////// Qt includes
-#include <QtGui>
-#include <QtXml>
-#include <QtGlobal>
-#include <QAction>
-#include <QtPlugin>
-#include <QPluginLoader> 
-
+#include<QtGui>
+#include<QtXml>
+#include<QtGlobal>
+#include<QAction>
+#include<QtPlugin>
+#include<QPluginLoader> 
+#include<QInputDialog>
+#include<QFileDialog>
+#include<QMessageBox>
 
 /////////////////////// Local includes
 #include "mainWindow.hpp"
@@ -52,7 +54,9 @@
 #include "sequenceEditorWnd.hpp"
 #include "mzLabWnd.hpp"
 #include "aboutDlg.hpp"
-#include "plugin_interfaces.hpp"
+#include "massListSorterDlg.hpp"
+#include "numeralsLocaleConverterDlg.hpp"
+#include "seqToolsDlg.hpp"
 
 
 namespace massXpert
@@ -63,7 +67,6 @@ namespace massXpert
     createActions();
     createMenus();
     createStatusBar();
-    loadPlugins();
 
     QPixmap pixmap(":/images/massxpert-icon-32.png");
     QIcon icon(pixmap);
@@ -75,6 +78,26 @@ namespace massXpert
     restoreGeometry(settings.value("main_window/geometry").toByteArray());
 
     setWindowTitle("massXpert");
+
+    // At this point, try to check if we should remind the user to
+    // cite the paper.
+
+    int runNumber = settings.value("globals/runNumber", 1).toInt();
+    
+    if (runNumber == 15)
+      {
+	AboutDlg *dlg = new AboutDlg(static_cast<QWidget *>(this));
+
+	dlg->showHowToCiteTab();
+	
+	dlg->show();
+	
+	settings.setValue("globals/runNumber", 1);
+      }
+    else
+      {
+	settings.setValue("globals/runNumber", ++runNumber);
+      }
   }
 
 
@@ -102,7 +125,7 @@ namespace massXpert
     if (!ok || filePath.isEmpty())
       {
 	filePath = 
-	  QFileDialog::getOpenFileName(this, tr("Open Definition File"),
+	  QFileDialog::getOpenFileName(this, tr("Open definition file"),
 					QDir::homePath(),
 					tr("XML files(*.xml *.XML)"));
       
@@ -158,7 +181,7 @@ namespace massXpert
 	// We could not get the filePath. Try by giving the user the
 	// opportunity to select a file from the filesystem.
 	filePath = 
-	  QFileDialog::getOpenFileName(this, tr("Open Definition File"),
+	  QFileDialog::getOpenFileName(this, tr("Open definition file"),
 					QDir::homePath(),
 					tr("XML files(*.xml *.XML)"));
       
@@ -196,9 +219,10 @@ namespace massXpert
     QString name;
   
     filePath = 
-      QFileDialog::getOpenFileName(this, tr("Open Sequence File"),
+      QFileDialog::getOpenFileName(this, tr("Open sequence file"),
 				    QDir::homePath(),
-				    tr("Sequence files(*.mxp *.mXp *.MXP)"));
+				    tr("Sequence files(*.mxp *.mXp *.MXP)"
+				       ";; All files(*.*)"));
       
     if (filePath.isNull() || filePath.isEmpty())
       return;
@@ -289,9 +313,10 @@ namespace massXpert
 	// We could not get the filePath. Try by giving the user the
 	// opportunity to select a file from the filesystem.
 	filePath = 
-	  QFileDialog::getOpenFileName(this, tr("Open Sequence File"),
+	  QFileDialog::getOpenFileName(this, tr("Open sequence file"),
 					QDir::homePath(),
-					tr("mxp files(*.mxp *.MXP)"));
+					tr("mxp files(*.mxp *.MXP)"
+					   ";; All files(*.*)"));
       }
     
     if (filePath.isNull() || filePath.isEmpty())
@@ -362,9 +387,10 @@ namespace massXpert
 	// We could not get the filePath. Try by giving the user the
 	// opportunity to select a file from the filesystem.
 	filePath = 
-	  QFileDialog::getOpenFileName(this, tr("Open Definition File"),
+	  QFileDialog::getOpenFileName(this, tr("Open definition file"),
 					QDir::homePath(),
-					tr("XML files(*.xml *.XML)"));
+					tr("XML files(*.xml *.XML)"
+					   ";; All files(*.*)"));
 	
 	if(filePath.isNull() || filePath.isEmpty())
 	  return;
@@ -451,7 +477,7 @@ namespace massXpert
 	// We could not get the filePath. Try by giving the user the
 	// opportunity to select a file from the filesystem.
 	filePath = 
-	  QFileDialog::getOpenFileName(this, tr("Open Definition File"),
+	  QFileDialog::getOpenFileName(this, tr("Open definition file"),
 					QDir::homePath(),
 					tr("XML files(*.xml *.XML)"));
       
@@ -478,6 +504,32 @@ namespace massXpert
     application->mzLabWndList()->append(mzLabWnd);
   }
   
+  void
+  MainWindow::massListSorter()
+  {
+    MassListSorterDlg *dialog = 
+      new MassListSorterDlg(this);
+    
+    dialog->show ();
+  }
+
+  void
+  MainWindow::numeralsLocaleConverter()
+  {
+    NumeralsLocaleConverterDlg *dialog = 
+      new NumeralsLocaleConverterDlg(this);
+    
+    dialog->show ();
+  }
+
+  void
+  MainWindow::seqTools()
+  {
+    SeqToolsDlg *dialog = 
+      new SeqToolsDlg(this);
+    
+    dialog->show ();
+  }
 
   void 
   MainWindow::about()
@@ -500,7 +552,7 @@ namespace massXpert
     // XpertDef Menu/Open PolChemDef
     openPolChemDefAct = new QAction(QIcon(":/images/open.png"), 
 				     tr("&Open..."), this); 
-    openPolChemDefAct->setShortcut(tr("Ctrl+O"));
+    openPolChemDefAct->setShortcut(tr("Ctrl+D,O"));
     openPolChemDefAct->setStatusTip 
      (tr("Open an existing polymer chemistry definition file"));
     connect(openPolChemDefAct, SIGNAL(triggered()), 
@@ -510,7 +562,7 @@ namespace massXpert
     // XpertDef Menu/New PolChemDef
     newPolChemDefAct = new QAction(QIcon(":/images/new.png"), 
 				    tr("&New..."), this);
-    newPolChemDefAct->setShortcut(tr("Ctrl+N"));
+    newPolChemDefAct->setShortcut(tr("Ctrl+D,N"));
     newPolChemDefAct->setStatusTip 
      (tr("Create a new polymer chemistry definition file"));
     connect(newPolChemDefAct, SIGNAL(triggered()), 
@@ -520,8 +572,8 @@ namespace massXpert
     // XpertCalc Menu/New Calculator
     newCalculatorAct = 
       new QAction(QIcon(":/images/new.png"), 
-		   tr("&Open Calculator"), this);
-    newCalculatorAct->setShortcut(tr("Ctrl+O"));
+		   tr("&Open calculator"), this);
+    newCalculatorAct->setShortcut(tr("Ctrl+C,O"));
     newCalculatorAct->setStatusTip 
      (tr("Open a new calculator window"));
     connect(newCalculatorAct, SIGNAL(triggered()), 
@@ -531,8 +583,8 @@ namespace massXpert
     // XpertEdit Menu/Open Sample Sequence
     openSampleSequenceAct = 
       new QAction(QIcon(":/images/new.png"), 
-		   tr("&Open Sample Sequence"), this);
-    openSampleSequenceAct->setShortcut(tr("Ctrl+O,S"));
+		   tr("&Open sample sequence"), this);
+    openSampleSequenceAct->setShortcut(tr("Ctrl+E,S"));
     openSampleSequenceAct->setStatusTip 
      (tr("Open an sample polymer sequence file"));
     connect(openSampleSequenceAct, SIGNAL(triggered()), 
@@ -540,8 +592,8 @@ namespace massXpert
 
     openSequenceAct = 
       new QAction(QIcon(":/images/new.png"), 
-		   tr("&Open Sequence"), this);
-    openSequenceAct->setShortcut(tr("Ctrl+O"));
+		   tr("&Open sequence"), this);
+    openSequenceAct->setShortcut(tr("Ctrl+E,O"));
     openSequenceAct->setStatusTip 
      (tr("Open an existing polymer sequence file"));
     connect(openSequenceAct, SIGNAL(triggered()), 
@@ -550,8 +602,8 @@ namespace massXpert
     // XpertEdit Menu/New Sequence
     newSequenceAct = 
       new QAction(QIcon(":/images/new.png"), 
-		   tr("&New Sequence"), this);
-    newSequenceAct->setShortcut(tr("Ctrl+N"));
+		   tr("&New sequence"), this);
+    newSequenceAct->setShortcut(tr("Ctrl+E,N"));
     newSequenceAct->setStatusTip 
      (tr("Create a new polymer sequence file"));
     connect(newSequenceAct, SIGNAL(triggered()), 
@@ -566,6 +618,34 @@ namespace massXpert
      (tr("Open a new mz lab window"));
     connect(mzLabAct, SIGNAL(triggered()), 
 	     this, SLOT(mzLab()));
+
+    //XpertTools
+    massListSorterAct =
+      new QAction(QIcon(":/images/new.png"), 
+		   tr("&mass List Sorter"), this);
+    massListSorterAct->setShortcut(tr("Ctrl+T,M"));
+    massListSorterAct->setStatusTip 
+     (tr("Sort masses in a list"));
+    connect(massListSorterAct, SIGNAL(triggered()), 
+	     this, SLOT(massListSorter()));
+    
+    numeralsLocaleConverterAct =
+      new QAction(QIcon(":/images/new.png"), 
+		   tr("&numerals Locale Converter"), this);
+    numeralsLocaleConverterAct->setShortcut(tr("Ctrl+T,C"));
+    numeralsLocaleConverterAct->setStatusTip 
+     (tr("Change the locale of numeral"));
+    connect(numeralsLocaleConverterAct, SIGNAL(triggered()), 
+	     this, SLOT(numeralsLocaleConverter()));
+    
+    seqToolsAct =
+      new QAction(QIcon(":/images/new.png"), 
+		   tr("&sequence Tools"), this);
+    seqToolsAct->setShortcut(tr("Ctrl+T,S"));
+    seqToolsAct->setStatusTip 
+     (tr("Tools for sequence manipulation"));
+    connect(seqToolsAct, SIGNAL(triggered()), 
+	     this, SLOT(seqTools()));
     
     // Help
     aboutAct = new QAction(tr("&About"), this);
@@ -613,8 +693,11 @@ namespace massXpert
 
     menuBar()->addSeparator();
 
-    // Plugins
-    pluginMenu = menuBar()->addMenu(tr("&Plugins"));
+    // Tools
+    toolsMenu = menuBar()->addMenu(tr("&Tools"));
+    toolsMenu->addAction(massListSorterAct);
+    toolsMenu->addAction(numeralsLocaleConverterAct);
+    toolsMenu->addAction(seqToolsAct);
   
     menuBar()->addSeparator();
 
@@ -631,152 +714,6 @@ namespace massXpert
     statusBar()->showMessage(tr("Ready"));
   }
 
-
-
-
-
-
-  ////////////////// BEGIN PLUGIN STUFF //////////////////////
-  ////////////////// BEGIN PLUGIN STUFF //////////////////////
-
-  void 
-  MainWindow::loadPlugins()
-  {
-    Application *application = static_cast<Application *>(qApp);
-
-    // SYSTEM PLUGIN DIR FIRST
-    QString pluginDir = application->configSettings()->systemPluginDir();
-    
-    QDir dir = QDir(pluginDir);
-  
-    if (dir.exists())
-      {
-	foreach(QString fileName, dir.entryList(QDir::Files))
-	  {
-	    QPluginLoader loader(dir.absoluteFilePath(fileName));
-	    QObject *plugin = loader.instance();
-	  
-	    if (plugin) 
-	      {
-		populatePluginMenus(plugin);
-		// qDebug() << "Loaded plugin:" << fileName;
-	      }
-	  }
-      }
-  
-    // USER PLUGIN DIR SECOND
-    pluginDir = application->configSettings()->userPluginDir();
-  
-    dir = QDir(pluginDir);
-  
-    if (dir.exists())
-      {
-	foreach(QString fileName, dir.entryList(QDir::Files))
-	  {
-	    QPluginLoader loader(dir.absoluteFilePath(fileName));
-	    QObject *plugin = loader.instance();
-      
-	    if (plugin) 
-	      {
-		populatePluginMenus(plugin);
-		// qDebug() << "Loaded plugin:" << fileName;
-	      }
-	  }
-      }
-  
-    pluginMenu->setEnabled(!pluginMenu->actions().isEmpty());
-  }
-
-
-  void 
-  MainWindow::populatePluginMenus(QObject *plugin)
-  {
-    SeqToolsPluginInterface *iSeqTools = 
-      qobject_cast<SeqToolsPluginInterface *>(plugin);
-
-    if (iSeqTools)
-      {
-	addToMenu(plugin, iSeqTools->tools(), 
-		   pluginMenu, SLOT(seqToolsPlugin()));
-      }
-
-    MassListSorterPluginInterface *iMassListSorter = 
-      qobject_cast<MassListSorterPluginInterface *>(plugin);
-
-    if (iMassListSorter)
-      {
-	addToMenu(plugin, iMassListSorter->tools(), 
-		   pluginMenu, SLOT(massListSorterPlugin()));
-      }
-
-    NumeralsLocaleConverterPluginInterface *iNumeralsLocaleConverter = 
-      qobject_cast<NumeralsLocaleConverterPluginInterface *>(plugin);
-
-    if (iNumeralsLocaleConverter)
-      {
-	addToMenu(plugin, iNumeralsLocaleConverter->tools(), 
-		   pluginMenu, SLOT(numeralsLocaleConverterPlugin()));
-      }
-  }
-
-
-  void 
-  MainWindow::addToMenu(QObject *plugin, const QStringList &texts, 
-			 QMenu *menu, const char *member)
-  {
-    foreach(QString text, texts) 
-      {
-	QAction *action = new QAction(text, plugin);
-	connect(action, SIGNAL(triggered()), this, member);
-	menu->addAction(action);
-      }
-  }
-
-
-  void
-  MainWindow::seqToolsPlugin()
-  {
-    QAction *action = qobject_cast<QAction *>(sender());
-  
-    SeqToolsPluginInterface *iSeqTools = 
-      qobject_cast<SeqToolsPluginInterface *>(action->parent());
-
-    iSeqTools->toolAtWork(action->text(), this);
-  }
-
-
-  void
-  MainWindow::massListSorterPlugin()
-  {
-    QAction *action = qobject_cast<QAction *>(sender());
-  
-    MassListSorterPluginInterface *iMassListSorter = 
-      qobject_cast<MassListSorterPluginInterface *>(action->parent());
-
-    iMassListSorter->toolAtWork(action->text(), this);
-  }
-
-
-  void
-  MainWindow::numeralsLocaleConverterPlugin()
-  {
-    QAction *action = qobject_cast<QAction *>(sender());
-  
-    NumeralsLocaleConverterPluginInterface *iNumeralsLocaleConverter = 
-      qobject_cast<NumeralsLocaleConverterPluginInterface *> 
-     (action->parent());
-
-    iNumeralsLocaleConverter->toolAtWork(action->text(), this);
-  }
-
-
-
-
-
-  ////////////////// END PLUGIN STUFF //////////////////////
-
-
-
   void 
   MainWindow::closeEvent(QCloseEvent *event)
   {
