@@ -451,7 +451,7 @@ namespace massXpert
     bool ok = false;
     quintptr monomerCastToInt = stringList.at(2).toInt(&ok);
   
-    Monomer *monomer =(Monomer *) monomerCastToInt;
+    Monomer *monomer =reinterpret_cast<Monomer *>(monomerCastToInt);
     int index = polymer->monomerIndex(monomer);
 
     if ((index + 1) != stringList.at(1).toInt(&ok))
