@@ -36,8 +36,8 @@
 
 
 /////////////////////// Qt includes
-#include <QMessageBox>
-
+#include<QMessageBox>
+#include<QFileDialog>
 
 /////////////////////// Local includes
 #include "mzCalculationDlg.hpp"
@@ -661,10 +661,11 @@ namespace massXpert
 
     mpa_resultsString->clear();
   
-    *mpa_resultsString += QObject::tr("\n---------------------------\n"
-				       "m/z Calculations: \n"
-				       "---------------------------\n");
-  
+    *mpa_resultsString += QObject::tr("# \n"
+                                      "# ---------------------------\n"
+                                      "# m/z Calculations: \n"
+                                      "# ---------------------------\n");
+    
     QString value;
   
     *mpa_resultsString += QObject::tr("\nSource conditions:\n"
