@@ -49,7 +49,7 @@
 #include "mzCalculationTreeViewModel.hpp"
 #include "mzCalculationTreeViewSortProxyModel.hpp"
 #include "ionizable.hpp"
-
+#include "oligomerList.hpp"
 
 namespace massXpert
 {
@@ -70,8 +70,15 @@ namespace massXpert
     QString m_resultsFilePath;
     //////////////////////////////////// The results-exporting strings.
 
-    IonizeRule m_ionizeRule;
     const PolChemDef *mp_polChemDef;
+
+    const QList<Atom *> &m_atomList;
+
+    OligomerList m_oligomerList;
+      
+    Formula m_formula;
+
+    IonizeRule m_ionizeRule;
     
     QList<Ionizable *> m_ionizableList;
 
@@ -101,10 +108,12 @@ namespace massXpert
     bool exportResultsClipboard();
     bool exportResultsFile();
     bool selectResultsFile();
+    bool calculateSpectrum();
     //////////////////////////////////// The results-exporting functions.
 
   public slots:
     void calculate();
+    void formulaCheckBoxToggled(bool);
     void exportResults(int);
   };
 
