@@ -19,7 +19,7 @@
    This software is free software; you can redistribute it and/or
    modify it under the terms of the GNU  General Public
    License version 3, as published by the Free Software Foundation.
-   
+
 
    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -41,13 +41,14 @@
 #include <QDebug>
 #include <QInputDialog>
 #include <QClipboard>
+#include <QGraphicsBlurEffect>
 
 
 /////////////////////// Local includes
 #include "mzLabInputOligomerTableViewDlg.hpp"
 #include "mzLabWnd.hpp"
 #include "mzLabInputOligomerTableViewModel.hpp"
-#include "fragmentOligomer.hpp"
+#include "application.hpp"
 
 
 namespace massXpert
@@ -56,28 +57,27 @@ namespace massXpert
   MzLabInputOligomerTableViewDlg::MzLabInputOligomerTableViewDlg
   (QWidget *parent,
    QString name,
-   MassType massType,
-   bool isFragment)
-    : QDialog(parent), 
-      m_name(name), 
-      m_isFragment(isFragment), 
+   MassType massType)
+    : QDialog(parent),
+      m_name(name),
       m_massType(massType)
   {
     Q_ASSERT(parent);
-    
+
     mp_mzLabWnd = static_cast<MzLabWnd *>(parent);
-        
+    mp_sequenceEditorWnd = 0;
+
     m_ui.setupUi(this);
 
+    // Set the delimiter to '$'.
+    m_ui.delimiterLineEdit->setText("$");
+    
     m_previousMassType = MXT_MASS_NONE;
 
     mpa_proxyModel = 0;
     mpa_oligomerTableViewModel = 0;
-    
+
     setupTableView();
-    
-    if(m_isFragment)
-      m_ui.isFragmentCheckBox->setChecked(true);
 
     if(m_massType == MXT_MASS_MONO)
       {
@@ -89,7 +89,7 @@ namespace massXpert
         m_ui.avgCheckBox->setChecked(true);
         m_ui.monoCheckBox->setChecked(false);
       }
-        
+
     m_ui.nameLineEdit->setText(m_name);
     setWindowTitle(tr("massXpert: mz Lab - %1")
                    .arg(m_name));
@@ -104,46 +104,49 @@ namespace massXpert
             this,
             SLOT(avgMassCheckBoxStateChanged(int)));
 
-    connect(m_ui.isFragmentCheckBox,
-	    SIGNAL(stateChanged(int)),
-	    this,
-	    SLOT(isFragmentCheckBoxStateChanged(int)));
-
     connect(m_ui.exportToClipboardPushButton,
-	    SIGNAL(clicked()),
-	    this,
-	    SLOT(exportToClipboard()));
+            SIGNAL(clicked()),
+            this,
+            SLOT(exportToClipboard()));
 
+    connect(m_ui.getFromClipboardPushButton,
+            SIGNAL(clicked()),
+            this,
+            SLOT(getFromClipboard()));
 
-  }
+    connect(m_ui.seqEditorWndPtrLineEdit,
+            SIGNAL(textChanged(const QString &)),
+            this,
+            SLOT(connectSeqEditorWnd(const QString &)));
+}
   
 
   MzLabInputOligomerTableViewDlg::~MzLabInputOligomerTableViewDlg()
   {
     while(m_oligomerList.size())
       delete m_oligomerList.takeFirst();
-    
+
     delete mpa_oligomerTableViewModel;
   }
 
 
-  void 
+  void
   MzLabInputOligomerTableViewDlg::closeEvent(QCloseEvent *event)
   {
     QDialog::closeEvent(event);
   }
-  
 
-  void 
+
+  void
   MzLabInputOligomerTableViewDlg::setName(const QString &name)
   {
     m_name = name;
-    
+
     m_ui.nameLineEdit->setText(m_name);
     setWindowTitle(tr("massXpert: mz Lab - %1")
                    .arg(m_name));
   }
-  
+
 
   QString
   MzLabInputOligomerTableViewDlg::name()
@@ -157,14 +160,22 @@ namespace massXpert
   {
     return m_oligomerList;
   }
-  
-  void 
+
+
+  SequenceEditorWnd *
+  MzLabInputOligomerTableViewDlg::sequenceEditorWnd()
+  {
+    return mp_sequenceEditorWnd;
+  }
+
+
+  void
   MzLabInputOligomerTableViewDlg::setupTableView()
   {
     // Model stuff all thought for sorting.
-    mpa_oligomerTableViewModel = 
+    mpa_oligomerTableViewModel =
       new MzLabInputOligomerTableViewModel(&m_oligomerList, this);
-      
+
     mpa_proxyModel = new MzLabInputOligomerTableViewSortProxyModel(this);
     mpa_proxyModel->setSourceModel(mpa_oligomerTableViewModel);
     mpa_proxyModel->setFilterKeyColumn(-1);
@@ -175,62 +186,50 @@ namespace massXpert
 
     m_ui.oligomerTableView->setMzLabWnd(mp_mzLabWnd);
     m_ui.oligomerTableView->setParentDlg(this);
-    
+
     mpa_oligomerTableViewModel->setTableView(m_ui.oligomerTableView);
     mpa_oligomerTableViewModel->setMzLabWnd(mp_mzLabWnd);
     mpa_oligomerTableViewModel->setParentDlg(this);
   }
+
+
+  QString
+  MzLabInputOligomerTableViewDlg::textFieldDelimiter()
+  {
+    // Get the delimiterLineEdit-contained string.
+
+    QString delimiter = m_ui.delimiterLineEdit->text();
+
+    if (delimiter.isEmpty())
+      {
+        delimiter = "$";
+      }
+    return delimiter;
+  }
   
   
-  int 
+  int
   MzLabInputOligomerTableViewDlg::duplicateOligomerData(const OligomerList &list)
   {
     int size = list.size();
-    
+
     for(int iter = 0; iter < size; ++iter)
       {
-	if(m_isFragment)
-	  {
-	    FragmentOligomer *iterOligomer = 
-	      dynamic_cast<FragmentOligomer *>(list.at(iter));
-	    
-	    FragmentOligomer *oligomer = new FragmentOligomer(*iterOligomer);
-	    
-	    mpa_oligomerTableViewModel->addOligomer(oligomer);
-	  }
-	else
-	  {
-	    Oligomer *oligomer = new Oligomer(*list.at(iter));
-            
-	    mpa_oligomerTableViewModel->addOligomer(oligomer);
-          }
+        Oligomer *oligomer = new Oligomer(*list.at(iter));
+        mpa_oligomerTableViewModel->addOligomer(oligomer);
       }
-          
+
     return mpa_oligomerTableViewModel->rowCount();
   }
-    
-    
+
+
   MassType
   MzLabInputOligomerTableViewDlg::massType()
   {
     //    qDebug() << __FILE__ << __LINE__ << "m_massType:" << m_massType;
     return m_massType;
   }
-    
-    
-  bool
-  MzLabInputOligomerTableViewDlg::isFragment()
-  {
-    return m_isFragment;
-  }
-    
-    
-  void
-  MzLabInputOligomerTableViewDlg::setFragment(bool fragment)
-  {
-    m_ui.isFragmentCheckBox->setChecked(fragment);
-  }
-  
+
 
   MassType
   MzLabInputOligomerTableViewDlg::previousMassType()
@@ -239,14 +238,14 @@ namespace massXpert
   }
 
 
-  void 
+  void
   MzLabInputOligomerTableViewDlg::setPreviousMassType(MassType type)
   {
     m_previousMassType = type;
   }
-  
 
-  MassType  
+
+  MassType
   MzLabInputOligomerTableViewDlg::massTypeQuery()
   {
     // Ask the user what should be the mass type of this dialog window.
@@ -260,25 +259,25 @@ namespace massXpert
 
     QPushButton *avgButton = msgBox.addButton(tr("avg masses"),
                                               QMessageBox::ActionRole);
-    
+
     msgBox.exec();
- 
-    if(msgBox.clickedButton() == monoButton) 
+
+    if(msgBox.clickedButton() == monoButton)
       {
         m_massType = MXT_MASS_MONO;
         m_ui.monoCheckBox->setCheckState(Qt::Checked);
         m_ui.avgCheckBox->setCheckState(Qt::Unchecked);
       }
-    else if(msgBox.clickedButton() == avgButton) 
+    else if(msgBox.clickedButton() == avgButton)
       {
         m_massType = MXT_MASS_AVG;
         m_ui.avgCheckBox->setCheckState(Qt::Checked);
         m_ui.monoCheckBox->setCheckState(Qt::Unchecked);
-      } 
-    
+      }
+
     return m_massType;
   }
-  
+
 
   void
   MzLabInputOligomerTableViewDlg::monoMassCheckBoxStateChanged(int state)
@@ -294,8 +293,8 @@ namespace massXpert
         m_ui.avgCheckBox->setCheckState(Qt::Checked);
       }
   }
-  
-  
+
+
   void
   MzLabInputOligomerTableViewDlg::avgMassCheckBoxStateChanged(int state)
   {
@@ -310,29 +309,19 @@ namespace massXpert
         m_ui.monoCheckBox->setCheckState(Qt::Checked);
       }
   }
-  
-  
-  void
-  MzLabInputOligomerTableViewDlg::isFragmentCheckBoxStateChanged(int state)
-  {
-    if (state == Qt::Checked)
-      m_isFragment = true;
-    else
-      m_isFragment = false;
-  }
-  
 
-  void 
+
+  void
   MzLabInputOligomerTableViewDlg::applyFormula(const Formula &formula,
                                                bool inPlace)
   {
     const PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
-    
+
     double mono = 0;
     double avg = 0;
 
     Formula local(formula);
-        
+
     if (!local.accountMasses(polChemDef->atomList(), &mono, &avg))
       {
         QMessageBox::warning(this,
@@ -344,53 +333,44 @@ namespace massXpert
                              .arg(formula.text()));
         return;
       }
-    
+
     if (inPlace)
       {
         // Just iterate in the oligomers and perform the computation.
-	
+
         int count = m_oligomerList.count();
 
         if(!count)
           return;
-	
+
         for(int iter = 0; iter < count; ++iter)
           {
             // First the mass
-            QModelIndex index = 
+            QModelIndex index =
               mpa_oligomerTableViewModel->index(iter,
                                                 MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
-            
+
             Q_ASSERT(index.isValid());
-	    
+
             Oligomer *oligomer = m_oligomerList.at(iter);
 
-            FragmentOligomer *fragOligomer =
-              dynamic_cast<FragmentOligomer *>(m_oligomerList.at(iter));
-	    
             int result = 0;
-	    
-            if (fragOligomer)
-              result = fragOligomer->deionize();
-            else
-              result = oligomer->deionize();
-	    
+
+            result = oligomer->deionize();
+
             // The deionization does not change the oligomer's member
             // IonizeRule, we do not need to store it. Further, we
             // want to know if something happened during the
             // deionize() call, as we'll have to reionize the oligomer
             // after having incremented the mass.
-	    
+
             if (m_massType == MXT_MASS_MONO)
               {
                 oligomer->incrementMass(mono, m_massType);
-		
+
                 if(result == 1)
                   {
-                    if (fragOligomer)
-                      fragOligomer->ionize();
-                    else
-                      oligomer->ionize();
+                    oligomer->ionize();
                   }
 
                 // Fake call to setData, because we want the model to
@@ -402,15 +382,12 @@ namespace massXpert
             else
               {
                 oligomer->incrementMass(avg, m_massType);
-		
+
                 if(result == 1)
                   {
-                    if (fragOligomer)
-                      fragOligomer->ionize();
-                    else
-                      oligomer->ionize();
+                    oligomer->ionize();
                   }
-		
+
                 // Fake call to setData, because we want the model to
                 // be updated with a call to dataChanged(index,
                 // index).
@@ -426,19 +403,14 @@ namespace massXpert
         dlgName.append(GlobElideText(formula.text()));
         dlgName.append(" )");
 
-        MzLabInputOligomerTableViewDlg *dlg = 
-          mp_mzLabWnd->newInputList(dlgName, m_massType, m_isFragment);
-        
+        MzLabInputOligomerTableViewDlg *dlg =
+          mp_mzLabWnd->newInputList(dlgName, m_massType);
+
         if(!dlg)
           return;
 
-        // The newly created dialog that it is opened to store
-        // fragmentation oligomer data.
-        if(m_isFragment)
-          dlg->setFragment(true);
-		
         int count = dlg->duplicateOligomerData(m_oligomerList);
-	
+
         if(count != m_oligomerList.count())
           qFatal("Fatal error at %s@%d. Program aborted.",
                  __FILE__, __LINE__);
@@ -446,59 +418,50 @@ namespace massXpert
         dlg->applyFormula(formula, true);
       }
   }
-  
 
-  void 
+
+  void
   MzLabInputOligomerTableViewDlg::applyMass(double mass,
                                             bool inPlace)
   {
     if (inPlace)
       {
         // Just iterate in the oligomers and perform the computation.
-	
+
         int count = m_oligomerList.count();
 
         if(!count)
           return;
-	
+
         for(int iter = 0; iter < count; ++iter)
           {
             // First the mass
-            QModelIndex index = 
-              mpa_oligomerTableViewModel->index(iter, 
+            QModelIndex index =
+              mpa_oligomerTableViewModel->index(iter,
                                                 MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
             Q_ASSERT(index.isValid());
-	    
+
             Oligomer *oligomer = m_oligomerList.at(iter);
-	    
-            FragmentOligomer *fragOligomer = 
-              dynamic_cast<FragmentOligomer *>(m_oligomerList.at(iter));
-	    
+
             int result = 0;
-	    
-            if (fragOligomer)
-              result = fragOligomer->deionize();
-            else
-              result = oligomer->deionize();
-	    
+
+            result = oligomer->deionize();
+
             // The deionization does not change the oligomer's member
             // IonizeRule, we do not need to store it. Further, we
             // want to know if something happened during the
             // deionize() call, as we'll have to reionize the oligomer
             // after having incremented the mass.
-	    
+
             if (m_massType == MXT_MASS_MONO)
               {
                 oligomer->incrementMass(mass, m_massType);
 
                 if(result == 1)
                   {
-                    if (fragOligomer)
-                      fragOligomer->ionize();
-                    else
-                      oligomer->ionize();
+                    oligomer->ionize();
                   }
-		
+
                 // Fake call to setData, because we want the model to
                 // be updated with a call to dataChanged(index,
                 // index).
@@ -508,15 +471,12 @@ namespace massXpert
             else
               {
                 oligomer->incrementMass(mass, m_massType);
-                
+
                 if(result == 1)
                   {
-                    if (fragOligomer)
-                      fragOligomer->ionize();
-                    else
-                      oligomer->ionize();
+                    oligomer->ionize();
                   }
-                
+
                 // Fake call to setData, because we want the model to
                 // be updated with a call to dataChanged(index,
                 // index).
@@ -533,30 +493,25 @@ namespace massXpert
         dlgName.append(" + ( ");
         dlgName.append(GlobElideText(massString));
         dlgName.append(" )");
-                
-        MzLabInputOligomerTableViewDlg *dlg = 
-          mp_mzLabWnd->newInputList(dlgName, m_massType, m_isFragment);
-        
+
+        MzLabInputOligomerTableViewDlg *dlg =
+          mp_mzLabWnd->newInputList(dlgName, m_massType);
+
         if(!dlg)
           return;
-	
-        // The newly created dialog that it is opened to store
-        // fragmentation oligomer data.
-        if(m_isFragment)
-          dlg->setFragment(true);
-        
+
         int count = dlg->duplicateOligomerData(m_oligomerList);
-	
+
         if(count != m_oligomerList.count())
           qFatal("Fatal error at %s@%d. Program aborted.",
                  __FILE__, __LINE__);
-	
+
         dlg->applyMass(mass, true);
       }
   }
 
 
-  void 
+  void
   MzLabInputOligomerTableViewDlg::applyThreshold(double threshold,
                                                  bool inPlace,
                                                  bool onMz)
@@ -564,34 +519,35 @@ namespace massXpert
     // If onMz is false, then the threshold is to be applied on the
     // deionized oligomers' mass. Otherwise, the threshold is to be
     // applied to the m/z value of the ionized oligomer.
-    
+
     if (inPlace)
       {
         // Just iterate in the oligomers and perform the computation.
-	
+
         int count = m_oligomerList.count();
 
         if(!count)
           return;
-	
+
         // Use count as an index, now, so we have to first decrement
         // it by one unit.
         --count;
-        
+
         while(count > -1)
           {
-            QModelIndex index = 
-              mpa_oligomerTableViewModel->index(count, 
+            QModelIndex index =
+              mpa_oligomerTableViewModel->index(count,
                                                 MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
-            Q_ASSERT(index.isValid());
-	    
+            if(!index.isValid())
+              qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
             Oligomer *oligomer = m_oligomerList.at(count);
-	    
+
             if (onMz)
               {
                 // We do not have to deionize the oligomer, as we are
                 // working on m/z values.
-		
+
                 if(oligomer->mass(m_massType) > threshold)
                   {
                   }
@@ -604,8 +560,8 @@ namespace massXpert
             else
               {
                 // We first have to deionize the oligomer, because the
-                // calculation is on M values. 
-		
+                // calculation is on M values.
+
                 // The deionization does not change the oligomer's
                 // member IonizeRule, we do not need to store
                 // it. Further, we want to know if something happened
@@ -614,7 +570,7 @@ namespace massXpert
                 // mass.
 
                 int result = oligomer->deionize();
-		
+
                 if(oligomer->mass(m_massType) > threshold)
                   {
                     if (result == 1)
@@ -643,112 +599,97 @@ namespace massXpert
         dlgName.append("( ");
         dlgName.append(GlobElideText(thresholdString));
         dlgName.append(" )");
-                
-        MzLabInputOligomerTableViewDlg *dlg = 
-          mp_mzLabWnd->newInputList(dlgName, m_massType, m_isFragment);
+
+        MzLabInputOligomerTableViewDlg *dlg =
+          mp_mzLabWnd->newInputList(dlgName, m_massType);
 
         if(!dlg)
           return;
-	
-        // The newly created dialog that it is opened to store
-        // fragmentation oligomer data.
-        if(m_isFragment)
-          dlg->setFragment(true);
-        
+
         int count = dlg->duplicateOligomerData(m_oligomerList);
-	
+
         if(count != m_oligomerList.count())
           qFatal("Fatal error at %s@%d. Program aborted.",
                  __FILE__, __LINE__);
-	
+
         dlg->applyThreshold(threshold, true, onMz);
       }
   }
-  
-  
-  void 
-  MzLabInputOligomerTableViewDlg::applyChargeIncrement(int increment, 
+
+
+  void
+  MzLabInputOligomerTableViewDlg::applyChargeIncrement(int increment,
                                                        bool inPlace)
   {
     if (!increment)
       return;
-    
+
     if (inPlace)
       {
         // Just iterate in the oligomers and perform the computation.
-	
+
         int count = m_oligomerList.count();
 
         if(!count)
           return;
-	
+
         for(int iter = 0; iter < count; ++iter)
           {
-            QModelIndex massIndex = 
-              mpa_oligomerTableViewModel->index(iter, 
+            QModelIndex massIndex =
+              mpa_oligomerTableViewModel->index(iter,
                                                 MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
             Q_ASSERT(massIndex.isValid());
-	    
-            QModelIndex chargeIndex = 
-              mpa_oligomerTableViewModel->index(iter, 
+
+            QModelIndex chargeIndex =
+              mpa_oligomerTableViewModel->index(iter,
                                                 MZ_LAB_INPUT_OLIGO_CHARGE_COLUMN);
             Q_ASSERT(chargeIndex.isValid());
-	    
+
             Oligomer *oligomer = m_oligomerList.at(iter);
 
-            FragmentOligomer *fragOligomer = 
-              dynamic_cast<FragmentOligomer *>(m_oligomerList.at(iter));
-	    
             int charge = 0;
 
-            if (fragOligomer)
-              charge = fragOligomer->charge();
-            else
-              charge = oligomer->charge();
+            charge = oligomer->charge();
 
             if (charge == -1)
               {
-                QMessageBox::warning 
-                  (this, 
+                QMessageBox::warning
+                  (this,
                    tr("massXpert: mz Lab"),
                    tr("%1@%2\n"
                       "Failed to get oligomer's charge.")
                    .arg(__FILE__)
                    .arg(__LINE__),
                    QMessageBox::Ok);
-		
+
                 return;
               }
-	    
+
             charge += increment;
-	    
+
             if (charge < 0)
               charge = 0;
-	    
+
             int result = 0;
-	    
-            if (fragOligomer)
-              result = fragOligomer->setCharge(charge);
-            else
-              result = oligomer->setCharge(charge);
-	    		    
+
+            result = oligomer->setCharge(charge);
 
             if (result == -1)
               {
-                QMessageBox::warning 
-                  (this, 
+                QMessageBox::warning
+                  (this,
                    tr("massXpert: mz Lab"),
                    tr("%1@%2\n"
                       "Failed to set oligomer's charge.")
                    .arg(__FILE__)
                    .arg(__LINE__),
                    QMessageBox::Ok);
-		
+
                 return;
               }
-	    
+
             // Update the mass value depending on the mass type.
-	    
+
             if (m_massType == MXT_MASS_MONO)
               {
                 // Fake call to setData, because we want the model to
@@ -760,7 +701,7 @@ namespace massXpert
               }
             else
               {
-		
+
                 // Fake call to setData, because we want the model to
                 // be updated with a call to dataChanged(index,
                 // index). First, we update the mass column and then
@@ -779,41 +720,36 @@ namespace massXpert
         dlgName.append("( ");
         dlgName.append(GlobElideText(incrementString));
         dlgName.append(" )");
-        
-         MzLabInputOligomerTableViewDlg *dlg = 
-          mp_mzLabWnd->newInputList(dlgName, m_massType, m_isFragment);
+
+        MzLabInputOligomerTableViewDlg *dlg =
+          mp_mzLabWnd->newInputList(dlgName, m_massType);
 
         if(!dlg)
           return;
-      
-        // The newly created dialog that it is opened to store
-        // fragmentation oligomer data.
-        if(m_isFragment)
-          dlg->setFragment(true);
-        
+
         int count = dlg->duplicateOligomerData(m_oligomerList);
-	
+
         if(count != m_oligomerList.count())
           qFatal("Fatal error at %s@%d. Program aborted.",
                  __FILE__, __LINE__);
-	
+
         dlg->applyChargeIncrement(increment, true);
       }
   }
 
 
-  void 
+  void
   MzLabInputOligomerTableViewDlg::applyIonizeRule(const IonizeRule &ionizeRule,
                                                   bool inPlace)
   {
     IonizeRule localIonizeRule = ionizeRule;
-  
+
     PolChemDef *polChemDef = mp_mzLabWnd->polChemDef();
-  
+
     if (!localIonizeRule.validate(polChemDef->atomList()))
       {
-        QMessageBox::warning 
-          (this, 
+        QMessageBox::warning
+          (this,
            tr("massXpert:mz Lab - Input list"),
            tr("%1@%2\n"
               "Failed to validate ionization rule.")
@@ -827,38 +763,32 @@ namespace massXpert
     if (inPlace)
       {
         // Just iterate in the oligomers and perform the computation.
-	
+
         int count = m_oligomerList.count();
-        
+
         if(!count)
           return;
-	
+
         for(int iter = 0; iter < count; ++iter)
           {
-            QModelIndex massIndex = 
-              mpa_oligomerTableViewModel->index(iter, 
-                                                MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
+            QModelIndex massIndex =
+              mpa_oligomerTableViewModel->
+              index(iter, MZ_LAB_INPUT_OLIGO_MASS_COLUMN);
             Q_ASSERT(massIndex.isValid());
-	    
-            QModelIndex chargeIndex = 
-              mpa_oligomerTableViewModel->index(iter, 
-                                                MZ_LAB_INPUT_OLIGO_CHARGE_COLUMN);
+
+            QModelIndex chargeIndex =
+              mpa_oligomerTableViewModel->
+              index(iter, MZ_LAB_INPUT_OLIGO_CHARGE_COLUMN);
             Q_ASSERT(chargeIndex.isValid());
-	    
+
             Oligomer *oligomer = m_oligomerList.at(iter);
-            
+
             // All we do is reionize the oligomer.
             
-            FragmentOligomer *fragOligomer = 
-              dynamic_cast<FragmentOligomer *>(m_oligomerList.at(iter));
-	    
-            if (fragOligomer)
-              fragOligomer->ionize(localIonizeRule);
-            else
-              oligomer->ionize(localIonizeRule);
-            
+            oligomer->ionize(localIonizeRule);
+
             // Update the mass value depending on the mass type.
-	    
+
             if (m_massType == MXT_MASS_MONO)
               {
                 // Fake call to setData, because we want the model to
@@ -891,30 +821,25 @@ namespace massXpert
         dlgName.append(", lev. ");
         dlgName.append(QString().setNum(localIonizeRule.level()));
         dlgName.append(" )");
-        
-        MzLabInputOligomerTableViewDlg *dlg = 
-          mp_mzLabWnd->newInputList(dlgName, m_massType, m_isFragment);
+
+        MzLabInputOligomerTableViewDlg *dlg =
+          mp_mzLabWnd->newInputList(dlgName, m_massType);
 
         if(!dlg)
           return;
-	
-        // The newly created dialog that it is opened to store
-        // fragmentation oligomer data.
-        if(m_isFragment)
-          dlg->setFragment(true);
 
         int count = dlg->duplicateOligomerData(m_oligomerList);
-	
+
         if(count != m_oligomerList.count())
           qFatal("Fatal error at %s@%d. Program aborted.",
                  __FILE__, __LINE__);
-        
+
         dlg->applyIonizeRule(localIonizeRule, true);
       }
-  }    
-  
-  
-  void 
+  }
+
+
+  void
   MzLabInputOligomerTableViewDlg::exportToClipboard()
   {
     // We are asked to prepare a list of (m/z,z) pairs according to
@@ -922,13 +847,84 @@ namespace massXpert
     // prepare a string.
 
     QString *text = m_ui.oligomerTableView->selectedDataAsPlainText();
-    
+
     QClipboard *clipboard = QApplication::clipboard();
 
     clipboard->setText(*text, QClipboard::Clipboard);
 
     delete text;
   }
-  
+
+
+  void
+  MzLabInputOligomerTableViewDlg::getFromClipboard()
+  {
+    // There must be something like this in the clipboard:
+
+    // 1050.15540333$3$cl-0#10+0#22#z=3$[89-100][186-202]
+    // (mass$charge$name$coordinates)
+
+    // or
+
+    // 1050.15540333$3$cl-0#10+0#22#z=3 (mass$charge$name)
+
+    // or
+
+    // 1050.15540333$3 (mass$charge)
+
+    // or
+
+    // 1050.15540333 (mass)
+
+    // We should delegate this work to to the table view itself,
+    // exactly as was done with the dropped data.
+
+    m_ui.oligomerTableView->pasteEvent();
+  }
+
+
+  SequenceEditorWnd *
+  MzLabInputOligomerTableViewDlg::connectSeqEditorWnd(const QString &text)
+  {
+    // The user is editing the pointer of the sequence editor window
+    // to which she wants to connect.
+
+    // First convert text to SequenceEditorWnd*
+    bool ok = false;
+    quintptr seqEdWndCastToInt = text.toInt(&ok);
+
+    if(seqEdWndCastToInt == 0 || ok == false)
+      {
+        mp_sequenceEditorWnd = 0;
+
+        QGraphicsBlurEffect *effect = new QGraphicsBlurEffect();
+
+        m_ui.seqEditorWndPtrLineEdit->
+          setGraphicsEffect(effect);
+
+        return mp_sequenceEditorWnd;
+      }
+
+    Application *application = static_cast<Application *>(qApp);
+
+    if(application->isSequenceEditorWnd
+       (reinterpret_cast<SequenceEditorWnd *>(seqEdWndCastToInt)))
+      {
+        mp_sequenceEditorWnd =
+          reinterpret_cast<SequenceEditorWnd *>(seqEdWndCastToInt);
+
+        return mp_sequenceEditorWnd;
+      }
+    else
+      {
+        mp_sequenceEditorWnd = 0;
+        QGraphicsBlurEffect *effect = new QGraphicsBlurEffect();
+
+        m_ui.seqEditorWndPtrLineEdit->
+          setGraphicsEffect(effect);
+
+        return mp_sequenceEditorWnd;
+      }
+  }
 
 } // namespace massXpert
