@@ -36,8 +36,8 @@
 
 
 /////////////////////// Qt includes
-#include <QMessageBox>
-
+#include<QMessageBox>
+#include<QFileDialog>
 
 /////////////////////// Local includes
 #include "polChemDefWnd.hpp"
@@ -352,9 +352,9 @@ namespace massXpert
     if (!formula.validate(atomList))
       {
 	statusBar()->showMessage(tr("Formula(%1) is invalid.")
-				   .arg(formula.formula()));
+				   .arg(formula.text()));
 
-	m_ui.leftCapLineEdit->setText(m_polChemDef.leftCap().formula());
+	m_ui.leftCapLineEdit->setText(m_polChemDef.leftCap().text());
       }
     else
       {
@@ -387,9 +387,9 @@ namespace massXpert
     if (!formula.validate(atomList))
       {
 	statusBar()->showMessage(tr("Formula(%1) is invalid.")
-				   .arg(formula.formula()));
+				   .arg(formula.text()));
 
-	m_ui.rightCapLineEdit->setText(m_polChemDef.rightCap().formula());
+	m_ui.rightCapLineEdit->setText(m_polChemDef.rightCap().text());
       }
     else
       {
@@ -420,14 +420,14 @@ namespace massXpert
     if (!formula.validate(atomList))
       {
 	statusBar()->showMessage(tr("Formula(%1) is invalid.")
-				   .arg(formula.formula()));
+				   .arg(formula.text()));
 
 	m_ui.ionizeFormulaLineEdit->setText 
 	 (m_polChemDef.ionizeRule().formula());
       }
     else
       {
-	m_polChemDef.ionizeRulePtr()->setFormula(formula.formula());
+	m_polChemDef.ionizeRulePtr()->setFormula(formula.text());
 
 	m_ui.ionizeFormulaLineEdit->setModified(false);
       
@@ -468,14 +468,14 @@ namespace massXpert
   PolChemDefWnd::setSingularData()
   {
     Formula formula = m_polChemDef.leftCap();
-    m_ui.leftCapLineEdit->setText(formula.formula());
+    m_ui.leftCapLineEdit->setText(formula.text());
   
     formula = m_polChemDef.rightCap();
-    m_ui.rightCapLineEdit->setText(formula.formula());
+    m_ui.rightCapLineEdit->setText(formula.text());
   
     IonizeRule ionizeRule = m_polChemDef.ionizeRule();
     formula = ionizeRule.formula();
-    m_ui.ionizeFormulaLineEdit->setText(formula.formula());
+    m_ui.ionizeFormulaLineEdit->setText(formula.text());
 
     m_ui.ionizeChargeSpinBox->setValue(ionizeRule.charge());
     m_ui.ionizeLevelSpinBox->setValue(ionizeRule.level());
