@@ -34,6 +34,10 @@
    51 Franklin St, Fifth Floor, Boston, MA 02110-1301, USA.
 */
 
+/////////////////////// Qt includes
+
+#include<QScrollBar>
+#include<QGraphicsItem>
 
 /////////////////////// Local includes
 #include "sequenceEditorGraphicsView.hpp"
@@ -85,8 +89,8 @@ namespace massXpert
 
     QScrollBar *vScrollBar = verticalScrollBar();
     connect(vScrollBar, SIGNAL(actionTriggered(int)),
-	     this, SLOT(vScrollBarActionTriggered(int)));
-
+            this, SLOT(vScrollBarActionTriggered(int)));
+    
     setHorizontalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     //setHorizontalScrollBarPolicy(Qt::ScrollBarAsNeeded);
   }
@@ -505,6 +509,9 @@ namespace massXpert
 			  visibleRows * m_requestedVignetteSize);
     
     mp_editorWnd->updateSelectedSequenceMasses();  
+
+    // Finally update the selection clipboard
+    mp_editorWnd->clipboardCopy(QClipboard::Selection);
   }
 
 
@@ -562,7 +569,7 @@ namespace massXpert
 	
 	positionCursor(*(mpa_selection->regionSelectionList().last()));
       }
-  }
+}
   
   
   void 
@@ -801,7 +808,7 @@ namespace massXpert
 	  {
 	    qDebug() << __FILE__ << __LINE__
 		      << "Failed to make svg renderer for monomer."
-		      << monomerCode.toAscii();
+		      << monomerCode;
 	    abort();
 	  }
       
@@ -950,7 +957,7 @@ namespace massXpert
     Q_ASSERT(monomerVignette);
   
     QList<QGraphicsItem *> childrenList = 
-      static_cast<QGraphicsItem *>(monomerVignette)->children();
+      static_cast<QGraphicsItem *>(monomerVignette)->childItems();
 
     for (int iter = 0; iter < childrenList.size(); ++iter)
       {
@@ -1036,7 +1043,7 @@ namespace massXpert
     Q_ASSERT(monomerVignette);
   
     QList<QGraphicsItem *> childrenList = 
-      static_cast<QGraphicsItem *>(monomerVignette)->children();
+      static_cast<QGraphicsItem *>(monomerVignette)->childItems();
 
     for (int iter = 0; iter < childrenList.size(); ++iter)
       {
@@ -1284,8 +1291,11 @@ namespace massXpert
 		QString text = QString("%1").arg(iter + 1);
 	      
 		QGraphicsTextItem *label = 
-		  new QGraphicsTextItem(text, 0, scene());
+		  new QGraphicsTextItem(text, 0);
 
+                // Now add the new item to the scene.
+                scene()->addItem(label);
+                
 		label->setPos(0,y);
 		
 // 		qDebug() << __FILE__ << __LINE__ 
@@ -1310,8 +1320,10 @@ namespace massXpert
 	    QString text = QString("%1").arg(iter + 1);
 	  
 	    QGraphicsTextItem *label = 
-	      new QGraphicsTextItem(text, 0, scene());
+	      new QGraphicsTextItem(text, 0);
 
+            scene()->addItem(label);
+            
 	    label->setPos(0,y);
 	  
 // 	    qDebug() << __FILE__ << __LINE__ 
@@ -2078,6 +2090,9 @@ namespace massXpert
 	  vScrollBarActionTriggered(QAbstractSlider::SliderSingleStepSub);
 
 	mp_editorWnd->updateSelectedSequenceMasses();
+
+        // Finally update the selection clipboard
+        mp_editorWnd->clipboardCopy(QClipboard::Selection);
       }
   
     event->accept();
