@@ -126,7 +126,7 @@ namespace massXpert
 
     for (int iter = 0 ; iter < m_isotopeList.size(); ++iter)
       {
-	Isotope *isotope = new Isotope(*m_isotopeList.at(iter));
+	Isotope *isotope = new Isotope(*(m_isotopeList.at(iter)));
       
 	other->m_isotopeList.append(isotope);
       }
@@ -507,14 +507,12 @@ namespace massXpert
 			const QList<Atom *> &refList,
 			Atom *other)
   {
-    Atom *atom = 0;
-  
     if (str.isEmpty())
       return -1;
 
     for (int iter = 0; iter < refList.size(); ++iter)
       {
-	atom = refList.at(iter);
+        Atom *atom = refList.at(iter);
 	Q_ASSERT(atom);
       
 	if(atom->m_symbol == str)
