@@ -231,12 +231,24 @@ namespace massXpert
     \return the formula as a string.
   */
   QString
-  Formula::formula() const
+  Formula::text() const
   {
     return m_formula;
   }
 
 
+  void
+  Formula::clear()
+  {
+    m_formula.clear();
+    m_plusFormula.clear();
+    m_minusFormula.clear();
+    
+    while(!m_atomCountList.isEmpty())
+      delete m_atomCountList.takeFirst();
+  }
+  
+    
   //! Sets the plus-formula.
   /*! 
   
@@ -460,7 +472,12 @@ namespace massXpert
     // the member datum.
 
     QString formula = m_formula;
-    
+
+    // qDebug() << __FILE__ << __LINE__
+    //          << "splitParts before working:"
+    //          << "m_formula:" << m_formula
+    //          << "text" << Formula::text();
+
     // One formula can be like this:
 
     // "Decomposed adenine" C5H4N5 +H 
@@ -488,6 +505,10 @@ namespace massXpert
 
 	if(m_plusFormula.length() > 0)
 	  {
+            // qDebug() << __FILE__ << __LINE__
+            //          << "splitParts: with m_plusFormula:"
+            //          << m_plusFormula;
+            
 	    if (!parse(refList, m_plusFormula, times, store, reset))
 	      return MXT_FORMULA_SPLIT_FAIL;
 	    else
@@ -573,6 +594,14 @@ namespace massXpert
 	while(!m_atomCountList.isEmpty())
 	  delete m_atomCountList.takeFirst();
       }
+
+
+    // qDebug() << __FILE__ << __LINE__
+    //          << "splitParts:"
+    //          << "right after splitting:"
+    //          << "m_formula:" << m_formula
+    //          << "text" << text();
+
   	
     // Now that we have reset if required the atomCountList, we need not
     // and we must not reset during the parsing below, otherwise if we
@@ -581,20 +610,42 @@ namespace massXpert
 
     if (m_plusFormula.length() > 0)
       {
-	if(!parse(refList, m_plusFormula, times, store, false))
-	  return MXT_FORMULA_SPLIT_FAIL;
+	bool res = parse(refList, m_plusFormula, times, 
+                         store, false /* reset */);
+        
+        // qDebug() << __FILE__ << __LINE__
+        //          << "splitParts:"
+        //          << "right after parse of m_plusFormula:"
+        //          << m_plusFormula
+        //          << "m_formula:" << m_formula
+        //          << "text" << text();
+        
+  	if(!res)
+          return MXT_FORMULA_SPLIT_FAIL;
 	else
 	  result = MXT_FORMULA_SPLIT_PLUS;
       }
-  
+    
+    
     if (m_minusFormula.length() > 0)
       {
-	if(!parse(refList, m_minusFormula, -times, store, false))
-	  return MXT_FORMULA_SPLIT_FAIL;
+        bool res = parse(refList, m_minusFormula, -times, 
+                         store, false /* reset */);
+        
+        // qDebug() << __FILE__ << __LINE__
+        //          << "splitParts:"
+        //          << "right after parse of m_minusFormula:"
+        //          << m_minusFormula
+        //          << "m_formula:" << m_formula
+        //          << "text" << text();
+        
+        if(!res)
+          return MXT_FORMULA_SPLIT_FAIL;
 	else
 	  result |= MXT_FORMULA_SPLIT_MINUS;
       }
-  
+
+    
     //   qDebug() << __FILE__ << __LINE__
     // 	    << formula.toAscii() << "-->" 
     // 	    << "(+)" << m_plusFormula.toAscii() 
@@ -636,7 +687,7 @@ namespace massXpert
     QChar curChar;
     QString parsedCount;
     QString parsedSymbol;
-    AtomCount *atomCount = 0;
+    AtomCount atomCount;
 
     bool wasDigit = false;
     bool gotUpper = false;
@@ -721,21 +772,17 @@ namespace massXpert
 		continue;
 	      }
 	  
-	    // There was a symbol being parsed. Create an object.
-	    atomCount = new AtomCount();
-	    atomCount->setSymbol(parsedSymbol);
+	    // There was a symbol being parsed. Fill-in the atomCount
+	    // object.
+	    atomCount.setSymbol(parsedSymbol);
 	  
 	    // Now we can prepare the field for the next one.
 	    parsedSymbol.clear();
 	    parsedSymbol.append(curChar);
 
 	    // Before going on, check if the symbol is correct.
-	    if (atomCount->isSymbolKnown(refList) == -1)
-	      {
-		delete atomCount;
-	      
-		return false;
-	      }
+	    if (atomCount.isSymbolKnown(refList) == -1)
+              return false;
 	  
 	    // If there was a count being parsed, we have to take it
 	    // into account.
@@ -746,29 +793,24 @@ namespace massXpert
 		// have to be able to know that water H2O has TWO
 		// hydrogen atoms in it.
 		bool isok = true;
-		atomCount->setCount(parsedCount.toInt(&isok, 10));
+		atomCount.setCount(parsedCount.toInt(&isok, 10));
 
-		if(atomCount->count() == 0 && !isok)
-		  {
-		    // The atom counts for nothing ! Or was there
-		    // an error in the conversion ?
-
-		    delete atomCount;
-		    
-		    return false;
-		  }
-	      
-		// But we remember that we have to take into account the
+		if(atomCount.count() == 0 && !isok)
+		  // The atom counts for nothing ! Or was there
+                  // an error in the conversion ?
+                  return false;
+                
+                // But we remember that we have to take into account the
 		// times parameter.
 	      
-		atomCount->setCount(atomCount->count() * times);
+		atomCount.setCount(atomCount.count() * times);
 
 		// Clear parsedCount for next count parsing round.
 		parsedCount.clear();
 	      }
 	    else
-	      atomCount->setCount(1 * times);
-	  
+	      atomCount.setCount(1 * times);
+            
 	    // We can now make sure that the atom gets represented
 	    // in the formula.atomCountList list of
 	    // AtomCount*. But for this we use a function that
@@ -777,15 +819,16 @@ namespace massXpert
 	    // accounting for a single atom symbol.
 
 	    if (store)
-	      {
-		if(!accountInList(atomCount, 0))
-		  delete atomCount;
-	      }
-	    else
-	      delete atomCount;
+              {
+                accountInList(atomCount);
 
+                // qDebug() << __FILE__ << __LINE__
+                //          << "accountInList:"
+                //          << atomCount.symbol() << atomCount.count();
+              }
+            
 	    // Let the people know what we got:
-	  
+            
 	    wasDigit = false;
 	    gotUpper = true;
 	  }
@@ -797,19 +840,13 @@ namespace massXpert
     // still have something cooking:
 
     // Thus we have to check that the last parsed atom
-    // symbol is correct. First allocate an AtomCount
-    // instance and set the symbol to it.
+    // symbol is correct.
 
-    atomCount = new AtomCount();
-    atomCount->setSymbol(parsedSymbol);
-
-    if (atomCount->isSymbolKnown(refList) == -1)
-      {
-	delete atomCount;
-
-	return false;
-      }
+    atomCount.setSymbol(parsedSymbol);
 
+    if (atomCount.isSymbolKnown(refList) == -1)
+      return false;
+    
     // And now we have to convert the string representation
     // of the atom count for that atom to int. In fact, we
     // have to be able to know that water H2O has TWO
@@ -824,113 +861,149 @@ namespace massXpert
 	// have to be able to know that water H2O has TWO
 	// hydrogen atoms in it.
 	bool isok = true;
-	atomCount->setCount(parsedCount.toInt(&isok, 10));
+	atomCount.setCount(parsedCount.toInt(&isok, 10));
 
-	if(atomCount->count() == 0 && !isok)
-	  {
-	    // The atom counts for nothing ! Or was there
-	    // an error in the conversion ?
-
-	    delete atomCount;
-
-	    return false;
-	  }
-	      
-	// But we remember that we have to take into account the
+	if(atomCount.count() == 0 && !isok)
+          // The atom counts for nothing ! Or was there
+          // an error in the conversion ?
+          return false;
+	  
+        // But we remember that we have to take into account the
 	// times parameter.
 	      
-	atomCount->setCount(atomCount->count() * times);
+	atomCount.setCount(atomCount.count() * times);
       }
     else
-      atomCount->setCount(1 * times);
+      atomCount.setCount(1 * times);
 	  
     // Finally, if asked by the caller, we can account for
     // this atom symbol/count also !
 
     if (store)
       {
-	if(!accountInList(atomCount, 0))
-	  delete atomCount;
+        accountInList(atomCount);
+    
+        // qDebug() << __FILE__ << __LINE__
+        //          << "accountInList:"
+        //          << atomCount.symbol() << atomCount.count();
+      }
+    
+    return true;
+  }
+
+
+  int
+  Formula::accountInList(const AtomCount &atomCount, int times)
+  {
+    int count = atomCount.count() * times;
+    int newCount = 0;
+    bool found = false;
+    
+    for(int iter = 0; iter < m_atomCountList.size(); ++iter)
+      {
+        if(m_atomCountList.at(iter)->symbol() == atomCount.symbol())
+          {
+            // qDebug() << __FILE__ << __LINE__
+            //          << "accountInList:"
+            //          << "same symbol:" << atomCount.symbol();
+           
+            found = true;
+            
+            // Same atom found. If the result of accounting is that
+            // the count is 0, then remove the atomCount instance
+            // alltogether. For example, admitting that there was 1
+            // Carbon atom in the list, and we account -1 Carbon, the
+            // result is that there is no Carbon atom remaining in the
+            // list. The call below would return 0. In that case
+            // remove an atomCount item of which the count is 0.
+            
+            newCount = m_atomCountList.at(iter)->account(count);
+            
+            if(!newCount)
+              {
+                delete m_atomCountList.takeAt(iter);
+                            
+                // qDebug() << __FILE__ << __LINE__
+                //          << "accountInList:"
+                //   "deleted atomCount instance "
+                //   "because count reached 0";
+              }
+            else
+              {
+                // qDebug() << __FILE__ << __LINE__
+                //          << "accountInList:"
+                //          << "new count:" 
+                //          << m_atomCountList.at(iter)->count();
+              }
+      
+            // We have found an atomCount instance by the same symbol,
+            // there should not be twice the same symbol in a formula,
+            // thus we can break the loop.
+            break;
+          }
+
+        continue;
+      }
+    // End of
+    // for(int iter = 0; iter < m_atomCountList.size(); ++iter)
+
+    if(!found)
+      {
+        // AtomCount not found locally. Thus make a copy and append to
+        // *this m_atomCountList..
+        
+        AtomCount *newAtomCount = new AtomCount(atomCount);
+        newAtomCount->setCount(count);
+        
+        m_atomCountList.append(newAtomCount);
+
+        newCount = count;
       }
     else
-      delete atomCount;
-
-    return true;
-  }
-
-
-  //! Accounts the \p atomCount instance into the list.
-  /*! The \p atomCount instance passed as parameter is accounted into
-    the list. If the list already contains a AtomCount instance by
-    the same symbol as \p atomCount, then no other instance is created,
-    but the count of the AtomCount object found in the list is
-    simply incremented.
-  
-    \param atomCount instance to be accounted in the list.
-  
-    \param newcount pointer to an integer into which to report the new
-    count for the \p atomCount. Defaults to 0, in which case no report
-    is done.
-  
-    \return true if a new AtomCount instance had to be allocated and
-    stored in the list, false if no AtomCount had to be created.
-  */
-  bool
-  Formula::accountInList(AtomCount *atomCount, 
-			  int *newcount) 
-  {
-    AtomCount * iter_atomCount = NULL;
-  
-    Q_ASSERT(atomCount != NULL);
-  
-    // We get a AtomCount instance pointer and are asked that that
-    // atomCount object be set to the member atomCountList. If an
-    // atomCount object by the same atomCount.symbol is already in that
-    // list, then its count member gets update with the one in the
-    // parameter object.
-  
-    for (int iter = 0; iter < m_atomCountList.size(); ++iter)
       {
-	iter_atomCount = m_atomCountList.at(iter);
-
-	if(iter_atomCount->symbol() == atomCount->symbol())
-	  {
-	    iter_atomCount->incrementCount(atomCount->count());
-	  
-	    // If the caller wants to get a numerical feedback on the
-	    // new count for current atomCount, then update newcount.
-	    if (newcount)
-	      *newcount = iter_atomCount->count();
-	  
-	    // Note that is the result of the operation above is to
-	    // have a 0-count item, we can remove it.
-
-	    if (!iter_atomCount->count())
-	      {
-		m_atomCountList.removeAt(iter);
-		
-		delete iter_atomCount;
-	      }
-	    
-	    // Because we update a pre-existing atomcount object, we do
-	    // not need to put the atomcount in the list. Return false,
-	    // so that the caller knows that it can delete that object.
-	    return false;
-	  }
+        // One AtomCount was found locally, newCount contains the new
+        // count for that found AtomCount.
       }
-  
-    // We did not find any suitable item in the List, so we just append
-    // the atomCount passed as parameter.
-    m_atomCountList.append(atomCount);
+    
+    // Update what's the text of the formula to represent what is in
+    // atomCount list.
+    m_formula = elementalComposition();
 
-    if (newcount != 0)
-      *newcount = atomCount->count();
-
-    // The atomCount object was truly added to the List.
-    return true;
+    return newCount;
   }
 
 
+  int 
+  Formula::accountInList(const QString &text, 
+                         const QList<Atom *> &atomRefList, 
+                         int times)
+  {
+    // We get a formula as an elemental composition and we want to
+    // account for that formula in *this formula.
+
+    // First off, validate the text.
+
+    Formula formula(text);
+    
+    if(!formula.validate(atomRefList, true, true))
+      return -1;
+    
+    // Now, for each AtomCount search one in the current formula.
+
+    const QList<AtomCount *> &otherAtomCountList = formula.atomCountList();
+    
+    for(int iter = 0; iter < otherAtomCountList.size(); ++iter)
+      accountInList(*otherAtomCountList.at(iter), times);
+
+    // Update what's the text of the formula to represent what is in
+    // atomCount list.
+    m_formula = elementalComposition();
+    
+    return 1;
+  }
+  
+
+
 //! Checks the syntax of the \p formula.
   /*! The syntax of the \p formula is checked by verifying that the
     letters and ciphers in the formula are correctly placed. That is, we
@@ -1140,9 +1213,18 @@ namespace massXpert
 			  double *mono, double *avg, int times)
   {
     // Note the 'times' param below.
-    if (splitParts(refList, times, true, true) == MXT_FORMULA_SPLIT_FAIL)
+    if (splitParts(refList, times, 
+                   true /* store */,
+                   true /* reset */) == MXT_FORMULA_SPLIT_FAIL)
       return false;
   
+    // qDebug() << __FILE__ << __LINE__
+    //          << "accountMasses:"
+    //          << "after splitParts:"
+    //          << "store: true ; reset: true"
+    //          << "m_formula:" << m_formula
+    //          << "text" << Formula::text();
+    
     for (int iter = 0; iter < m_atomCountList.size(); ++iter)
       {
 	AtomCount *atomCount = 0;
@@ -1258,12 +1340,24 @@ namespace massXpert
             negativeStringList.append(QString("%1%2")
                                       .arg(atomCount->symbol())
                                       .arg(-1 * atomCount->count()));
+
+            // qDebug() << __FILE__ << __LINE__
+            //          << "negative atomCount:" 
+            //          << atomCount->symbol() 
+            //          << "/" 
+            //          << (-1 * atomCount->count());
           }
         else
           {  
             positiveStringList.append(QString("%1%2")
                                       .arg(atomCount->symbol())
                                       .arg(atomCount->count()));
+
+            // qDebug() << __FILE__ << __LINE__
+            //          << "positive atomCount:" 
+            //          << atomCount->symbol() 
+            //          << "/" 
+            //          << atomCount->count();
           }
       }
     
@@ -1325,6 +1419,9 @@ namespace massXpert
 
     positiveComponentString += positiveStringList.join("");
 
+    // qDebug() << __FILE__ << __LINE__
+    //          <<"positiveComponentString:" << positiveComponentString;
+    
 
     // The negative component
     // ======================
@@ -1368,6 +1465,9 @@ namespace massXpert
 
     negativeComponentString += negativeStringList.join("");
 
+    // qDebug() << __FILE__ << __LINE__
+    //          <<"negativeComponentString:" << negativeComponentString;
+
     // Create the final elemental formula that comprises both the
     // positive and negative element. First the positive element and
     // then the negative one. Only append the negative one, prepended
@@ -1379,6 +1479,9 @@ namespace massXpert
       elementalComposition += QString("-%1")
       .arg(negativeComponentString);
 
+    // qDebug() << __FILE__ << __LINE__
+    //          <<"elementalComposition:" << elementalComposition;
+    
     return elementalComposition;
   }
 
