@@ -153,9 +153,9 @@ namespace massXpert
 
     if (m_calcOptions.monomerEntities() & MXT_MONOMER_CHEMENT_CROSS_LINK)
       {
-        qDebug() << __FILE__ << __LINE__
-                 << "Fragmentation calculations take "
-          "into account the cross-links";
+        // qDebug() << __FILE__ << __LINE__
+        //          << "Fragmentation calculations take "
+        //   "into account the cross-links";
         
         // Let's put one of the fragmentation options (the first) so that
         // we can get the indices of the oligomer to fragment.
@@ -170,9 +170,9 @@ namespace massXpert
         QList<int> crossLinkedMonomerIndexList;
         int partials = 0;
         
-        qDebug() << __FILE__ << __LINE__
-                 << "Fragmentation options:"
-                 << fragOptions->startIndex() << fragOptions->endIndex();
+        // qDebug() << __FILE__ << __LINE__
+        //          << "Fragmentation options:"
+        //          << fragOptions->startIndex() << fragOptions->endIndex();
         
         mp_polymer->crossLinkedMonomerIndexList(fragOptions->startIndex(),
                                                 fragOptions->endIndex(),
@@ -378,27 +378,41 @@ namespace massXpert
 	// to be valid. For example, one drag and drop operation might
 	// copy this oligomer into a mzLab dialog window where its
 	// ionization rule validity might be challenged. Because this
-	// fragmentation oligomer will bear only its intrinsic 1
-	// charge, we should set the level member of the ionization to
-	// 0.
+	// fragmentation oligomer will be a neutral species, we should
+	// set the level member of the ionization to 0.
 	
 	IonizeRule ionizeRule(m_ionizeRule);
 	ionizeRule.setLevel(0);
 	
-	FragmentOligomer *oligomer1 = 
-	  new FragmentOligomer(mp_polymer, "NOT_SET", fragOptions.name(),
-                               Ponderable(), 
-                               ionizeRule, false,
-                               iter, iter, m_calcOptions);
-	
+	Oligomer *oligomer1 = 
+	  new Oligomer(mp_polymer,
+                       "NOT_SET",
+                       fragOptions.name() /*fragSpec.m_name*/,
+                       Ponderable(), 
+                       ionizeRule,
+                       m_calcOptions,
+                       false /*isIonized*/,
+                       iter /*startIndex*/, iter /*endIndex*/);
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "right after creation with ionizerule but no charge:"
+        //          << oligomer1->mono();
+        	
 	localOptions.setCapping(MXT_CAP_NONE);
       
+        // Since version 3.6.0, the formula of the fragmentation
+        // specification should yield a neutral molecular species,
+        // which is then ionized according to the current ionization
+        // rule in the editor window. The levels of this ionization
+        // rule are set by the user in the fragmentation dialog
+        // window, which default to a single level of ionization.
 
-	// The calculation of the masses is not performed by applying
-	// any ionization rule, as the fragmentation rule itself will
-	// yield an ionized species(it should be singly-charged). Thus
-	// we pass an invalid ionizeRule object(upon creation, an
-	// ionize rule is invalid).
+        // The first step is to calculate the masses of the fragment
+        // oligomer without taking into account the ionization,
+        // because we still have other things to account for that
+        // might interfere with the mass of the fragment. So we pass
+        // an invalid ionizeRule object(upon creation, an ionize rule
+        // is invalid).
 	IonizeRule rule;
 
 	if(!oligomer1->calculateMasses(&localOptions, &rule))
@@ -408,12 +422,12 @@ namespace massXpert
 	    return -1;
 	  }
 
+        // qDebug() << __FILE__ << __LINE__
+        //          << "right after calculateMasses with invalid ionizerule:"
+        //          << oligomer1->mono();
+
 	const QList<Atom *> &refList = mp_polChemDef->atomList();
       
-	// It is at this precise moment that the generated oligomer will
-	// have a single charge onto it: by the accounting of the
-	// fragmentation rule's formula.
-
 	if(!fragOptions.formula().isEmpty())    
 	  if (!fragOptions.Formula::accountMasses(refList, oligomer1))
 	    {
@@ -421,7 +435,11 @@ namespace massXpert
 
 	      return -1;
 	    }
-      
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "right after accountMasses for fragSpec formula:"
+        //          << oligomer1->mono();
+
 	// At this moment, the new fragment might be challenged for
 	// the fragmented monomer's contribution. For example, in
 	// nucleic acids, it happens that during a fragmentation, the
@@ -429,7 +447,7 @@ namespace massXpert
 	// away. This is implemented in massXpert with the ability to
 	// tell the fragmenter that upon fragmentation the mass of the
 	// monomer is to be removed. The skeleton mass is then added
-	// to the formula of the fragmentation pattern.
+	// to the formula of the fragmentation pattern (FragSpec).
 
 	int monomerContrib = fragOptions.monomerContribution();
 
@@ -448,18 +466,22 @@ namespace massXpert
 		return -1;
 	      }
 	  }
-      
+        
+        // qDebug() << __FILE__ << __LINE__
+        //          << "right after accountMasses for monomer contribution:"
+        //          << oligomer1->mono();
+
 	// At this point we should check if the fragmentation
 	// specification includes fragmentation rules that apply to this
-	// fragment.
+	// fragment. FragOptions is derived from FragSpec.
 
 	for(int jter = 0; jter < fragOptions.ruleList().size(); ++jter)
 	  {
 	    // The accounting of the fragrule is performed on a
-	    // singly-charged oligomer, as defined by the fragmentation
-	    // formula. Later, we'll have to take into account the fact
-	    // that the user might want to calculate fragment m/z with
-	    // z>1.
+	    // neutral oligomer, as defined by the fragmentation
+	    // formula. Later, we'll have to take into account the
+	    // fact that the user might want to calculate fragment m/z
+	    // with z>1.
 
 	    FragRule *fragRule = fragOptions.ruleList().at(jter);
 	  
@@ -468,8 +490,8 @@ namespace massXpert
 	  
 	    // Each fragrule triggers the creation of a new oligomer.
 
-	    FragmentOligomer *oligomer2 = 
-	      new FragmentOligomer(*oligomer1);
+	    Oligomer *oligomer2 = 
+	      new Oligomer(*oligomer1);
 
 	    if (!accountFragRule(fragRule, false, iter, 
 				  MXT_FRAG_END_NONE, oligomer2))
@@ -480,14 +502,19 @@ namespace massXpert
 		return -1;
 	      }
 
-	    // At this point we have the fragment oligomer that bears
-	    // the "default" fragmentation specification
-	    // formula-driven charge, that is z=1.
-	    
-	    FragmentOligomer *newOligomer = 
-	      new FragmentOligomer(*oligomer2);
+            // qDebug() << __FILE__ << __LINE__
+            //          << "right after accountFragRule:"
+            //          << oligomer1->mono();
 
-            int charge = 1;
+	    // At this point we have the fragment oligomer within a
+	    // neutral state, because starting with version 3.6.0, the
+	    // fragmentation specification should yield a neutral
+	    // molecular species.
+            
+            Oligomer *newOligomer = 
+	      new Oligomer(*oligomer2);
+
+            int charge = 0;
             
             // We can immediately set the name of template oligomer on which
             // to base the creation of the derivative formula-based
@@ -600,12 +627,13 @@ namespace massXpert
 	    // specification. 
 
 	    // So, first create an oligomer with the "default"
-	    // fragmentation specification-driven 1+ charge.  
+	    // fragmentation specification-driven neutral state (that
+	    // is, charge = 0).
 
-	    FragmentOligomer *newOligomer = 
-	      new FragmentOligomer(*oligomer1);
+	    Oligomer *newOligomer = 
+	      new Oligomer(*oligomer1);
 
-            int charge = 1;
+            int charge = 0;
             
             // We can immediately set the name of template oligomer on which
             // to base the creation of the derivative formula-based
@@ -676,8 +704,7 @@ namespace massXpert
 
               while(!ionizeLevelOligomerList->isEmpty())
                 {
-                  FragmentOligomer *iterOligomer = 
-                    static_cast<FragmentOligomer *>(ionizeLevelOligomerList->takeFirst());
+                  Oligomer *iterOligomer = ionizeLevelOligomerList->takeFirst();
                   
                   mp_oligomerList->append(iterOligomer);
                   ++count;
@@ -812,11 +839,10 @@ namespace massXpert
 	   (mp_polymer,
 	     MXT_POLYMER_CHEMENT_LEFT_END_MODIF,
 	     &ponderableTemp);
-      
-	// It is at this precise moment that the generated oligomer will
-	// have a single charge onto it: by the accounting of the
-	// fragmentation rule's formula as computed above in the
-	// ponderableTemp instance used to construct the oligomer.
+
+        // As of version 3.6.0, the polymer chemistry definition
+        // should define a formula for the FragSpec that yields a
+        // fragment oligomer having no charge: in a neutral state.
 
 	// We create an oligomer which is not ionized(false) but that
 	// bears the default ionization rule, because this oligomer
@@ -831,11 +857,15 @@ namespace massXpert
 	IonizeRule ionizeRule(m_ionizeRule);
 	ionizeRule.setLevel(0);
 	
-	FragmentOligomer *oligomer1 = 
-	  new FragmentOligomer(mp_polymer, "NOT_SET", fragOptions.name(),
-                               ponderableTemp, 
-                               ionizeRule, false,
-                               fragOptions.startIndex(), iter, m_calcOptions);
+	Oligomer *oligomer1 = 
+	  new Oligomer(mp_polymer,
+                       "NOT_SET",
+                       fragOptions.name() /*fragSpec.m_name*/,
+                       ponderableTemp, 
+                       ionizeRule,
+                       m_calcOptions,
+                       false /*isIonized*/,
+                       fragOptions.startIndex(), iter /*endIndex*/);
 	
 	// At this moment, the new fragment might be challenged for the
 	// fragmented monomer's side chain contribution. For example, in
@@ -884,8 +914,8 @@ namespace massXpert
 	  
 	    // Each fragrule triggers the creation of a new oligomer.
 
-	    FragmentOligomer *oligomer2 = 
-	      new FragmentOligomer(*oligomer1);
+	    Oligomer *oligomer2 = 
+	      new Oligomer(*oligomer1);
 
 	    if (!accountFragRule(fragRule, false, iter, 
 				  MXT_FRAG_END_LEFT, oligomer2))
@@ -896,15 +926,15 @@ namespace massXpert
 		return -1;
 	      }
 
-	    // At this point we have the fragment oligomer that bears
-	    // the "default" fragmentation specification formula-driven
-	    // charge. Let's create one such fragment oligomer for the
-	    // record(see the 1 charge for the oligomer).
+	    // At this point we have the fragment oligomer within a
+	    // neutral state, because starting with version 3.6.0, the
+	    // fragmentation specification should yield a neutral
+	    // molecular species.
 
-	    FragmentOligomer *newOligomer = 
-	      new FragmentOligomer(*oligomer2);
+	    Oligomer *newOligomer = 
+	      new Oligomer(*oligomer2);
 
-            int charge = 1;
+            int charge = 0;
             
             // We can immediately set the name of template oligomer on which
             // to base the creation of the derivative formula-based
@@ -1017,12 +1047,13 @@ namespace massXpert
 	    // specification. 
 
 	    // So, first create an oligomer with the "default"
-	    // fragmentation specification-driven 1+ charge.  
+	    // fragmentation specification-driven neutral state (that
+	    // is, charge = 0).
 
-	    FragmentOligomer *newOligomer = 
-	      new FragmentOligomer(*oligomer1);
+	    Oligomer *newOligomer = 
+	      new Oligomer(*oligomer1);
 	  
-            int charge = 1;
+            int charge = 0;
             
             // We can immediately set the name of template oligomer on which
             // to base the creation of the derivative formula-based
@@ -1093,9 +1124,7 @@ namespace massXpert
 
               while(!ionizeLevelOligomerList->isEmpty())
                 {
-                  FragmentOligomer *iterOligomer = 
-                    static_cast<FragmentOligomer *>
-                    (ionizeLevelOligomerList->takeFirst());
+                  Oligomer *iterOligomer = ionizeLevelOligomerList->takeFirst();
                   
                   mp_oligomerList->append(iterOligomer);
                   ++count;
@@ -1232,10 +1261,9 @@ namespace massXpert
 	     MXT_POLYMER_CHEMENT_RIGHT_END_MODIF,
 	     &ponderableTemp);
       
-	// It is at this precise moment that the generated oligomer will
-	// have a single charge onto it: by the accounting of the
-	// fragmentation rule's formula as computed above in the
-	// ponderableTemp instance used to construct the oligomer.
+        // As of version 3.6.0, the polymer chemistry definition
+        // should define a formula for the FragSpec that yields a
+        // fragment oligomer having no charge: in a neutral state.
 
 	// We create an oligomer which is not ionized(false) but that
 	// bears the default ionization rule, because this oligomer
@@ -1246,16 +1274,20 @@ namespace massXpert
 	// fragmentation oligomer will bear only its intrinsic 1
 	// charge, we should set the level member of the ionization to
 	// 0.
-	
+
 	IonizeRule ionizeRule(m_ionizeRule);
 	ionizeRule.setLevel(0);
 	
-	FragmentOligomer *oligomer1 = 
-	  new FragmentOligomer(mp_polymer, "NOT_SET", fragOptions.name(),
-				ponderableTemp, 
-				ionizeRule, false, 
-				iter, fragOptions.endIndex(), m_calcOptions);
-
+	Oligomer *oligomer1 = 
+	  new Oligomer(mp_polymer,
+                       "NOT_SET",
+                       fragOptions.name() /*fragSpec.m_name*/,
+                       ponderableTemp, 
+                       ionizeRule,
+                       m_calcOptions,
+                       false /*isIonized*/, 
+                       iter /*startIndex*/, fragOptions.endIndex() /*endIndex*/);
+        
 	// At this moment, the new fragment might be challenged for the
 	// fragmented monomer's side chain contribution. For example, in
 	// nucleic acids, it happens that during a fragmentation, the
@@ -1302,8 +1334,8 @@ namespace massXpert
 	  
 	    // Each fragrule triggers the creation of a new oligomer.
 
-	    FragmentOligomer *oligomer2 = 
-	      new FragmentOligomer(*oligomer1);
+	    Oligomer *oligomer2 = 
+	      new Oligomer(*oligomer1);
 
 	    if (!accountFragRule(fragRule, false, iter, 
 				  MXT_FRAG_END_RIGHT, oligomer2))
@@ -1314,15 +1346,15 @@ namespace massXpert
 		return -1;
 	      }
 
-	    // At this point we have the fragment oligomer that bears
-	    // the "default" fragmentation specification formula-driven
-	    // charge. Let's create one such fragment oligomer for the
-	    // record(see the 1 charge for the oligomer).
+	    // At this point we have the fragment oligomer within a
+	    // neutral state, because starting with version 3.6.0, the
+	    // fragmentation specification should yield a neutral
+	    // molecular species.
 
-	    FragmentOligomer *newOligomer = 
-	      new FragmentOligomer(*oligomer2);
+	    Oligomer *newOligomer = 
+	      new Oligomer(*oligomer2);
 
-            int charge = 1;
+            int charge = 0;
             
             // We can immediately set the name of template oligomer on which
             // to base the creation of the derivative formula-based
@@ -1435,12 +1467,13 @@ namespace massXpert
 	    // specification. 
 
 	    // So, first create an oligomer with the "default"
-	    // fragmentation specification-driven 1+ charge.  
+	    // fragmentation specification-driven neutral state (that
+	    // is, charge = 0).
 
-	    FragmentOligomer *newOligomer = 
-	      new FragmentOligomer(*oligomer1);
+	    Oligomer *newOligomer = 
+	      new Oligomer(*oligomer1);
 	  
-            int charge = 1;
+            int charge = 0;
             
             // We can immediately set the name of template oligomer on which
             // to base the creation of the derivative formula-based
@@ -1511,8 +1544,7 @@ namespace massXpert
 
               while(!ionizeLevelOligomerList->isEmpty())
                 {
-                  FragmentOligomer *iterOligomer = 
-                    static_cast<FragmentOligomer *>(ionizeLevelOligomerList->takeFirst());
+                  Oligomer *iterOligomer = ionizeLevelOligomerList->takeFirst();
                   
                   mp_oligomerList->append(iterOligomer);
                   ++count;
@@ -1792,8 +1824,7 @@ namespace massXpert
     
     // The oligomer that we get as parameter is the template on which
     // to base the derivatives on the basis of the formulas.
-    FragmentOligomer *templateOligomer = 
-      static_cast<FragmentOligomer *>(oligomerList->first());
+    Oligomer *templateOligomer = oligomerList->first();
     
     // At this point check if the fragOptions.m_formulaList has items
     // in it.
@@ -1805,8 +1836,8 @@ namespace massXpert
         Formula *formula = formulaList.at(iter);
     
         // We will apply the formula to a copy of the template oligomer
-        FragmentOligomer *newOligomer = 
-          new FragmentOligomer(static_cast<FragmentOligomer &>(*templateOligomer));
+        Oligomer *newOligomer = 
+          new Oligomer(*templateOligomer);
         
         if(!formula->accountMasses(atomRefList, newOligomer))
           {
@@ -1816,7 +1847,11 @@ namespace massXpert
             delete newOligomer;
             continue;
           }
-        
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "right after accountFormulaIteration:"
+        //          << newOligomer->mono();
+
         // The new oligomer could be generated correctly. Append the
         // formula to its name, so that we'll be able to recognize it.
         
@@ -1871,23 +1906,29 @@ namespace massXpert
         
     while(!oligomerList->isEmpty())
       {
-        FragmentOligomer *curOligomer = 
-          static_cast<FragmentOligomer *>(oligomerList->takeFirst());
+        Oligomer *curOligomer = oligomerList->takeFirst();
 
         // First of remove the currently iterated oligomer from the
-        // list and append it right away to the new oligomerList.
-        newOligomerList->append(curOligomer);
-
+        // list, we won't need it as it is charged 0. But we need to
+        // make a copy of it before deleting it at the end of the
+        // ionization loop below.
+        
         // At this point use that oligomer as a template for the
         // ionization level stuff.
 
-        for (int kter = startIonizeLevel; kter < endIonizeLevel; ++kter)
+        for (int kter = startIonizeLevel; kter < endIonizeLevel + 1; ++kter)
           {
             IonizeRule ionizeRule(m_ionizeRule);
             ionizeRule.setLevel(kter);
 
-            FragmentOligomer *newOligomer = new FragmentOligomer(*curOligomer);
+            Oligomer *newOligomer = new Oligomer(*curOligomer);
 	  
+            // qDebug() << __FILE__ << __LINE__
+            //          << "right before ionizing with ionizerule:"
+            //          << newOligomer->mono()
+            //          << "with ionize level =" << kter
+            //          << " charge of the oligomer: " << newOligomer->charge();
+            
             // If the result of the call below is -1, then that
             // means that there was an error and we should return
             // immediately. If it is 0, then that means that no
@@ -1911,7 +1952,13 @@ namespace massXpert
 		
                 continue;
               }
-	      
+
+            // qDebug() << __FILE__ << __LINE__
+            //          << "right after ionizing with ionizerule:"
+            //          << newOligomer->mono()
+            //          << "with ionize level =" << kter
+            //          << " charge of the oligomer: " << newOligomer->charge();
+            	      
             // At this point the ionization did indeed perform
             // something interesting, craft the name of the resulting
             // oligomer and set it. We must of the name of the
@@ -1934,10 +1981,14 @@ namespace massXpert
         // End of 
         // for (int kter = startIonizeLevel; kter < endIonizeLevel; ++kter)
 
+        // We can now delete the oligomer that was used as a template,
+        // and which had a charge of 0.
+        delete(curOligomer);
+        
         // If there was a single failure, we get here with wasFailure
         // set to true. In that case, free the newOligomerList and
         // return NULL.
-
+        
         if(wasFailure)
           {
             // Empty the new oligomer list and delete it.
