@@ -342,18 +342,29 @@ namespace massXpert
   int 
   Ionizable::ionize()
   {
-    if (m_isIonized)
-      return 0;
-    
     if (!m_ionizeRule.isValid())
       return -1;
     
+    if (m_isIonized)
+      return 0;
+    
     // At this point perform the ionization proper.
     
     Formula formula(m_ionizeRule.formula());
     
     Ponderable temp(*this);
     
+    // qDebug() << __FILE__ << __LINE__ 
+    //          << "Before ionization:\n"
+    //          << "Ionizable's charge / level:"
+    //          << m_ionizeRule.charge() << "/" <<  m_ionizeRule.level()
+    //          << " -- "
+    //          << "Ionizable's whole charge:"
+    //          << m_ionizeRule.charge() * m_ionizeRule.level()
+    //          << " -- "
+    //          << "Mono:" << temp.mono() << "Avg:" << temp.avg()
+    //          << "\n\n";
+    
     double localMono = 0;
     double localAvg = 0;
 
@@ -370,24 +381,34 @@ namespace massXpert
     // charge and level values of m_ionizeRule cannot be <= 0 because
     // otherwise the m_ionizRule would not have validated.
     
+    int ionCharge = m_ionizeRule.charge() * m_ionizeRule.level();
+
     m_mono += localMono;
-    m_mono = m_mono /(m_ionizeRule.charge() * m_ionizeRule.level());
+    m_mono = m_mono /ionCharge;
 
     m_avg += localAvg;
-    m_avg = m_avg /(m_ionizeRule.charge() * m_ionizeRule.level());
+    m_avg = m_avg / ionCharge;
     
     // Of course, we now are ionized.
     m_isIonized = true;
     
-//     qDebug() << __FILE__ << __LINE__ 
-// 	      << "Total charge:"
-// 	      << m_ionizeRule.charge() * m_ionizeRule.level()
-// 	      << "After ionization: Mono:" << m_mono << "Avg:" << m_avg;
-
+    // qDebug() << __FILE__ << __LINE__ 
+    //          << "After ionization:\n"
+    //          << "Ionizable's charge / level:"
+    //          << m_ionizeRule.charge() << "/" <<  m_ionizeRule.level() 
+    //          << " -- "
+    //          << "Ionizable's whole charge:"
+    //          << m_ionizeRule.charge() * m_ionizeRule.level()
+    //          << " -- "
+    //          << "Mono:" << m_mono << "Avg:" << m_avg
+    //          << "\n\n";
+    
     // If something changed in the masses, then return 1, otherwise
     // return 0.
-    if (temp != *this)
-      return 1;
+    if (temp != static_cast<Ponderable>(*this))
+      {
+        return 1;
+      }
     
     return 0;
   }
@@ -509,8 +530,6 @@ namespace massXpert
   int 
   Ionizable::ionize(Ionizable *ionizable, const IonizeRule &ionizeRule)
   {
-    Q_ASSERT(ionizable);
-    
     if (!ionizeRule.isValid())
       return -1;
     
