@@ -19,7 +19,7 @@
    This software is free software; you can redistribute it and/or
    modify it under the terms of the GNU  General Public
    License version 3, as published by the Free Software Foundation.
-   
+
 
    This software is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
@@ -45,8 +45,8 @@ namespace massXpert
 {
 
   //! Constructs a monomer.
-  /*! 
-  
+  /*!
+
     \param polChemDef Polymer chemistry definition. Cannot be 0.
 
     \param name Name. Cannot be empty.
@@ -55,9 +55,9 @@ namespace massXpert
 
     \param formula Formula.
   */
-  Monomer::Monomer(const PolChemDef *polChemDef, QString name, 
+  Monomer::Monomer(const PolChemDef *polChemDef, QString name,
                    QString code, QString formula)
-    : PolChemDefEntity(polChemDef, name), 
+    : PolChemDefEntity(polChemDef, name),
       Formula(formula), Ponderable(0, 0),
       m_code(code)
   {
@@ -75,7 +75,7 @@ namespace massXpert
   /*! The newly created monomer is initialized using \c this. The
     initialization is shallow, as the property list is not used in the
     initialization.
-  
+
     \return The newly created monomer, which should be deleted when no
     longer in use.
   */
@@ -90,16 +90,16 @@ namespace massXpert
 
     if (mpa_modifList)
       {
-	other->mpa_modifList = new QList<Modif *>();
+        other->mpa_modifList = new QList<Modif *>();
 
-	for(int iter = 0; iter < mpa_modifList->size(); ++iter)
-	  {
-	    Modif *modif = new Modif(*mpa_modifList->at(iter));
-	  
-	    other->mpa_modifList->append(modif);
-	  }
+        for(int iter = 0; iter < mpa_modifList->size(); ++iter)
+          {
+            Modif *modif = new Modif(*mpa_modifList->at(iter));
+
+            other->mpa_modifList->append(modif);
+          }
       }
-  
+
     return other;
   }
 
@@ -107,17 +107,17 @@ namespace massXpert
   //! Modifies \p other to be similar(shallow cloning) to \p this.
   /*! The copying is shallow, as the data in the property list are not
     copied.
-  
+
     \param other monomer.
   */
   void
   Monomer::clone(Monomer *other) const
   {
     Q_ASSERT(other);
-  
+
     if (other == this)
       return;
-  
+
     PolChemDefEntity::clone(other);
     Formula::clone(other);
     Ponderable::clone(other);
@@ -129,21 +129,21 @@ namespace massXpert
 
     if (mpa_modifList)
       {
-	if(!other->mpa_modifList)
-	  other->mpa_modifList = new QList<Modif *>();
+        if(!other->mpa_modifList)
+          other->mpa_modifList = new QList<Modif *>();
 
-	for(int iter = 0; iter < mpa_modifList->size(); ++iter)
-	  {
-	    Modif *modif = new Modif(*mpa_modifList->at(iter));
-	  
-	    other->mpa_modifList->append(modif);
-	  } 
+        for(int iter = 0; iter < mpa_modifList->size(); ++iter)
+          {
+            Modif *modif = new Modif(*mpa_modifList->at(iter));
+
+            other->mpa_modifList->append(modif);
+          }
       }
     else
       {
-	delete(other->mpa_modifList);
-      
-	other->mpa_modifList = 0;
+        delete(other->mpa_modifList);
+
+        other->mpa_modifList = 0;
       }
   }
 
@@ -159,33 +159,33 @@ namespace massXpert
   {
     if (&other == this)
       return;
-  
+
     PolChemDefEntity::mold(other);
     Formula::mold(other);
     Ponderable::mold(other);
-  
+
     m_code = other.m_code;
 
     if (mpa_modifList)
       qDeleteAll(*mpa_modifList);
-  
+
     if (other.mpa_modifList)
       {
-	if(!mpa_modifList)
-	  mpa_modifList = new QList<Modif *>();
+        if(!mpa_modifList)
+          mpa_modifList = new QList<Modif *>();
 
-	for(int iter = 0; iter < other.mpa_modifList->size(); ++iter)
-	  {
-	    Modif *modif = new Modif(*other.mpa_modifList->at(iter));
-	  
-	    mpa_modifList->append(modif);
-	  } 
+        for(int iter = 0; iter < other.mpa_modifList->size(); ++iter)
+          {
+            Modif *modif = new Modif(*other.mpa_modifList->at(iter));
+
+            mpa_modifList->append(modif);
+          }
       }
     else
       {
-	delete(mpa_modifList);
-      
-	mpa_modifList = 0;
+        delete(mpa_modifList);
+
+        mpa_modifList = 0;
       }
   }
 
@@ -214,20 +214,20 @@ namespace massXpert
   //! Tests equality.
   /*! This is a shallow comparison, as properties are not involved in
     the comparison.
-  
+
     \param other monomer to compare with \p this.
 
     \return true if monomers are similar, false otherwise.
   */
-  bool 
+  bool
   Monomer::operator ==(const Monomer &other) const
   {
     int tests = 0;
-  
+
     tests += PolChemDefEntity::operator ==(other);
     tests += Formula::operator ==(other);
     tests += Ponderable::operator ==(other);
-  
+
     tests +=(m_code == other.m_code);
 
     if (mpa_modifList->size() != other.mpa_modifList->size())
@@ -235,48 +235,48 @@ namespace massXpert
 
     for (int iter = 0; iter < mpa_modifList->size(); ++iter)
       {
-	if(mpa_modifList->at(iter) != other.mpa_modifList->at(iter))
-	  return false;
+        if(mpa_modifList->at(iter) != other.mpa_modifList->at(iter))
+          return false;
       }
-    
+
     if (tests < 4)
       return false;
-    
+
     return true;
   }
-  
+
 
   //! Tests inequality.
   /*! This is a shallow comparison, as properties are not involved in
     the comparison.
-  
+
     \param other monomer to compare with \p this.
 
     \return true if monomers differ, false otherwise.
   */
-  bool 
+  bool
   Monomer::operator !=(const Monomer &other) const
   {
     int tests = 0;
-  
+
     tests += PolChemDefEntity::operator !=(other);
     tests += Formula::operator !=(other);
     tests += Ponderable::operator !=(other);
-  
+
     tests +=(m_code != other.m_code);
-  
+
     if (mpa_modifList->size() != other.mpa_modifList->size())
       return true;
-  
+
     for (int iter = 0; iter < mpa_modifList->size(); ++iter)
       {
-	if(mpa_modifList->at(iter) != other.mpa_modifList->at(iter))
-	  return true;
+        if(mpa_modifList->at(iter) != other.mpa_modifList->at(iter))
+          return true;
       }
 
     if (tests > 0)
       return true;
-    
+
     return false;
   }
 
@@ -286,9 +286,9 @@ namespace massXpert
     \attention This is not a validation, as this syntax checking only
     makes sure that the code is made of one uppercase character at first
     position and of lowercase characters following it.
-  
+
     \return true if successful, false otherwise.
-  
+
     \sa validate().
   */
   bool
@@ -299,10 +299,10 @@ namespace massXpert
     // All the remaining authorized characters have to be
     // lowercase.
     int codeLength = mp_polChemDef->codeLength();
-  
+
     if (m_code.length() < 1 || m_code.length() > codeLength)
       return false;
-  
+
     // Note that the actual monomer code length might be less than the
     // codeLength member datum in the polymer chemistry
     // definition. Which is why we have to make sure we test that before
@@ -310,44 +310,44 @@ namespace massXpert
 
     for (int iter = 0 ; iter < m_code.size(); ++iter)
       {
-	// Test that the m_code length is not greater than codeLength.
-	if(iter + 1 > codeLength)
-	  return false;
-      
-	// And now check the character syntax.
-	QChar curChar = m_code.at(iter);
-      
-	if(iter == 0)
-	  {
-	    if (curChar.category() != QChar::Letter_Uppercase)
-	      return false;
-	  }
-	else if (curChar.category() == QChar::Letter_Uppercase)
-	  return false;
+        // Test that the m_code length is not greater than codeLength.
+        if(iter + 1 > codeLength)
+          return false;
+
+        // And now check the character syntax.
+        QChar curChar = m_code.at(iter);
+
+        if(iter == 0)
+          {
+            if (curChar.category() != QChar::Letter_Uppercase)
+              return false;
+          }
+        else if (curChar.category() == QChar::Letter_Uppercase)
+          return false;
       }
-  
+
     return true;
   }
 
 
   //! Searches \p this monomer in a list according to code.
   /*! The list of reference monomers belongs to the monomer.
-  
+
     \return the index of the found monomer or -1 if none is found or if
     the code is empty.
   */
-  int 
+  int
   Monomer::isCodeKnown() const
   {
     const QList<Monomer*> &refList = mp_polChemDef->monomerList();
-  
+
     if (m_code.isEmpty())
       return -1;
-  
+
     for (int iter = 0 ; iter < refList.size() ; ++iter)
       {
-	if(refList.at(iter)->m_code == m_code)
-	  return iter;
+        if(refList.at(iter)->m_code == m_code)
+          return iter;
       }
 
     return -1;
@@ -359,63 +359,63 @@ namespace massXpert
     argument \p str in the monomer list \p refList. If such monomer is
     found, and if \p other is non-0, \p this monomer's data are copied
     into \p other.
-  
+
     \param str code.
 
     \param refList list of reference monomers.
-  
+
     \param other monomer in which to copy the data from the found
     monomer. Defaults to 0, in which case no copying occurs.
-  
+
     \return the int index of the found monomer or -1 if no monomer instance is
     found or if \p str is empty.
   */
-  int 
-  Monomer::isCodeInList(const QString &str, 
+  int
+  Monomer::isCodeInList(const QString &str,
                         const QList<Monomer*> &refList,
                         Monomer *other)
   {
     Monomer *monomer = 0;
-  
+
     if (str.isEmpty())
       return -1;
-  
+
     for (int iter = 0; iter < refList.size(); ++iter)
       {
-	monomer = refList.at(iter);
-	Q_ASSERT(monomer);
-      
-	if(monomer->m_code == str)
-	  {
-	    if (other)
-	      monomer->clone(other);
-	  
-	    return iter;
-	  }
+        monomer = refList.at(iter);
+        Q_ASSERT(monomer);
+
+        if(monomer->m_code == str)
+          {
+            if (other)
+              monomer->clone(other);
+
+            return iter;
+          }
       }
-  
+
     return -1;
   }
 
 
   //! Searches \p this monomer in a list according to name.
   /*! The list of reference monomers belongs to the monomer.
-  
+
     \return the index of the found monomer or -1 if none is found or if
     the name is empty.
   */
-  int 
+  int
   Monomer::isNameKnown() const
   {
     const QList<Monomer*> &refList = mp_polChemDef->monomerList();
-  
+
     if (m_name.isEmpty())
       return -1;
-  
+
     for (int iter = 0 ; iter < refList.size() ; ++iter)
       {
-	if(refList.at(iter)->m_name == m_name)
-	  return iter;
+        if(refList.at(iter)->m_name == m_name)
+          return iter;
       }
 
     return -1;
@@ -427,41 +427,41 @@ namespace massXpert
     argument \p str in the monomer list \p refList. If such monomer is
     found, and if \p other is non-0, \p this monomer's data are copied
     into \p other.
-  
+
     \param str name.
 
     \param refList list of reference monomers.
-  
+
     \param other monomer in which to copy the data from the found
     monomer. Defaults to 0, in which case no copying occurs.
-  
+
     \return the int index of the found monomer or -1 if no monomer instance is
     found or if \p str is empty.
   */
-  int 
-  Monomer::isNameInList(const QString &str, 
+  int
+  Monomer::isNameInList(const QString &str,
                         const QList<Monomer*> &refList,
                         Monomer *other)
   {
     Monomer *monomer = 0;
-  
+
     if (str.isEmpty())
       return -1;
-  
+
     for (int iter = 0; iter < refList.size(); ++iter)
       {
-	monomer = refList.at(iter);
-	Q_ASSERT(monomer != 0);
-      
-	if(monomer->m_name == str)
-	  {
-	    if (other != 0)
-	      monomer->clone(other);
-	  
-	    return iter;
-	  }
+        monomer = refList.at(iter);
+        Q_ASSERT(monomer != 0);
+
+        if(monomer->m_name == str)
+          {
+            if (other != 0)
+              monomer->clone(other);
+
+            return iter;
+          }
       }
-  
+
     return -1;
   }
 
@@ -478,9 +478,9 @@ namespace massXpert
   {
     return Formula::text();
   }
-  
 
-  bool 
+
+  bool
   Monomer::isModifTarget(const Modif &modif) const
   {
     // Pure convenience function.
@@ -491,12 +491,12 @@ namespace massXpert
 
 
   bool
-  Monomer::modify(Modif *modif, bool override, 
-		   QStringList &errorList)
+  Monomer::modify(Modif *modif, bool override,
+                  QStringList &errorList)
   {
-    // Will take ownership of the modif. 
+    // Will take ownership of the modif.
 
-    // We have to check two things: 
+    // We have to check two things:
 
     // 1. That *this monomer is actually a target of the modification
     // at hand(or that we can override limitations);
@@ -506,34 +506,34 @@ namespace massXpert
     // correct for adding one more.
 
     Q_ASSERT(modif);
-  
+
     if (!isModifTarget(*modif) && !override)
       {
-	// This monomer is not a target for the modif, and no override
-	// is allowed.
+        // This monomer is not a target for the modif, and no override
+        // is allowed.
 
-	errorList << QObject::tr("\t%1 not target of modif %2 "
-				  "(no overriding allowed)")
-	  .arg(m_name)
-	  .arg(modif->name());
-      
-	return false;
+        errorList << QObject::tr("\t%1 not target of modif %2 "
+                                 "(no overriding allowed)")
+          .arg(m_name)
+          .arg(modif->name());
+
+        return false;
       }
-    
+
     int count = modifCount(modif->name());
-    
+
     if (count >= modif->maxCount() && !override)
       {
-	// This monomer has already the maximum count of 'modif' objects.
-	
-	errorList << QObject::tr("\t%1 already modified %2 times "
-				  "(no overriding allowed)")
-	  .arg(m_name)
-	  .arg(count);
-	
-	return false;
+        // This monomer has already the maximum count of 'modif' objects.
+
+        errorList << QObject::tr("\t%1 already modified %2 times "
+                                 "(no overriding allowed)")
+          .arg(m_name)
+          .arg(count);
+
+        return false;
       }
- 
+
     // We are going to add one modification to the list of
     // modifications. Note however, that if the monomer had never been
     // modified(or all of its modifications had been removed), then its
@@ -541,16 +541,16 @@ namespace massXpert
 
     if (!mpa_modifList)
       mpa_modifList = new QList<Modif *>();
-  
+
     mpa_modifList->append(modif);
-  
+
     return true;
   }
 
 
   //! Unmodifies the monomer for the specific modif.
   /*! \param modif modification to be removed.
-  
+
     \return always true.
   */
   bool
@@ -562,30 +562,30 @@ namespace massXpert
     // cannot be that the list of modifs be 0 or empty.
     Q_ASSERT(mpa_modifList);
     Q_ASSERT(mpa_modifList->size());
-  
+
     // Will remove only one item, even if we call removeAll() because
     // there is only one 'modif' pointer to Modif.
     int ret = mpa_modifList->removeAll(modif);
-  
+
     // Only one item should have been found in the list.
     if (ret != 1)
       qFatal("%s@%d", __FILE__, __LINE__);
-    
+
     // If we removed the last item, free the list.
     if (!mpa_modifList->size())
       {
-	delete mpa_modifList;
-      
-	mpa_modifList = 0;
+        delete mpa_modifList;
+
+        mpa_modifList = 0;
       }
-  
+
     return true;
   }
 
 
   //! Unmodifies the monomer totally(all its modifications).
   /*!
-  
+
     \return always true.
   */
   bool
@@ -593,44 +593,44 @@ namespace massXpert
   {
     if (mpa_modifList)
       {
-	qDeleteAll(*mpa_modifList);
-  
-	delete mpa_modifList;
+        qDeleteAll(*mpa_modifList);
+
+        delete mpa_modifList;
       }
-  
+
     return true;
   }
 
 
-  bool 
+  bool
   Monomer::isModified() const
   {
     if (mpa_modifList && mpa_modifList->size())
       return true;
-  
+
     return false;
   }
 
 
-  int 
+  int
   Monomer::modifCount(const QString& name)
   {
     int count = 0;
 
     if (!mpa_modifList)
       return 0;
-        
+
     for (int iter = 0; iter < mpa_modifList->size(); ++iter)
       {
-	Modif *modif = mpa_modifList->at(iter);
-	
-	if(name == modif->name())
-	  ++count;
+        Modif *modif = mpa_modifList->at(iter);
+
+        if(name == modif->name())
+          ++count;
       }
-    
+
     return count;
   }
-  
+
 
 
   //! Validates \p this monomer.
@@ -639,14 +639,14 @@ namespace massXpert
     concerned by the validation process because the presence of at least
     one isotope in the isotope list essentially makes sure that masses
     are available(see below).
-  
+
     \li the name cannot be empty;
-  
+
     \li the code cannot be empty and must pass test of
     checkCodeSyntax(int max_length);
-  
+
     \li the formula must validate.
-  
+
     \return true if the monomer was successfully validated, false otherwise.
 
     \sa checkCodeSyntax(int max_length).
@@ -658,20 +658,20 @@ namespace massXpert
 
     if (m_name.isEmpty())
       return false;
-  
+
     if (!checkCodeSyntax())
       return false;
 
     if (!Formula::validate(refList))
       return false;
-  
+
     if (mpa_modifList)
       {
-	for(int iter = 0; iter < mpa_modifList->size(); ++iter)
-	  {
-	    if (!mpa_modifList->at(iter)->validate())
-	      return false;
-	  }
+        for(int iter = 0; iter < mpa_modifList->size(); ++iter)
+          {
+            if (!mpa_modifList->at(iter)->validate())
+              return false;
+          }
       }
 
     return true;
@@ -681,35 +681,35 @@ namespace massXpert
   //! Calculates the masses(mono and avg).
   /*! The calculation is performed by computing the mono and avg masses
     of the formula.
-  
+
     \return true if calculations were successful, false otherwise.
 
     \sa Formula::splitParts()
   */
-  bool 
+  bool
   Monomer::calculateMasses(int how)
   {
     const QList<Atom *> &refList = mp_polChemDef->atomList();
 
     m_mono = 0;
     m_avg = 0;
-  
+
     if (!Formula::accountMasses(refList, &m_mono, &m_avg))
       return false;
 
     if (how & MXT_MONOMER_CHEMENT_MODIF)
       {
-	if(mpa_modifList)
-	  {
-	    for (int iter = 0; iter < mpa_modifList->size(); ++iter)
-	      {
-		Modif *modif = mpa_modifList->at(iter);
-	      
-		modif->accountMasses(&m_mono, &m_avg);
-	      }
-	  }
+        if(mpa_modifList)
+          {
+            for (int iter = 0; iter < mpa_modifList->size(); ++iter)
+              {
+                Modif *modif = mpa_modifList->at(iter);
+
+                modif->accountMasses(&m_mono, &m_avg);
+              }
+          }
       }
-  
+
     return true;
   }
 
@@ -723,7 +723,7 @@ namespace massXpert
     \p this monomer's monoisotopic mass is 200 and average mass is 202,
     then the computation leads to \p *mono = 100 + 2 * 200 and \p *avg =
     101 + 2 * 202.
-  
+
     \param mono monoisotopic mass to update. Defaults to 0, in which
     case this mass is not updated.
 
@@ -735,15 +735,15 @@ namespace massXpert
 
     \return always true.
   */
-  bool 
+  bool
   Monomer::accountMasses(double *mono, double *avg, int times) const
   {
     if (mono)
       *mono += m_mono * times;
-  
+
     if (avg)
       *avg += m_avg * times;
-  
+
     return true;
   }
 
@@ -758,22 +758,22 @@ namespace massXpert
     \p this monomer's monoisotopic mass is 200 and average mass is 202,
     then the computation leads to \p *mono = 100 + 2 * 200 and \p *avg =
     101 + 2 * 202.
-  
+
     \param ponderable The ponderable of which the masses need to be updated.
 
     \param times times that the increment should be performed. Defaults
     to 1.
-  
+
     \return always true.
   */
-  bool 
+  bool
   Monomer::accountMasses(Ponderable *ponderable, int times) const
   {
     Q_ASSERT(ponderable);
-  
+
     ponderable->rmono() += m_mono * times;
     ponderable->ravg() += m_avg * times;
-    
+
     return true;
   }
 
@@ -782,21 +782,21 @@ namespace massXpert
   //! Parses a monomer XML element from a polymer chemistry definition.
   /*! Parses the monomer XML element passed as argument and for each
     encountered data will set the data to \p this monomer(this is
-    called XML rendering). 
+    called XML rendering).
 
     After setting all the data, \p this monomer calculates it masses and
     validates itself. If any of these steps fails, the error is reported
     by returning false.
-  
+
     \param element XML element to be parsed and rendered.
-  
+
     \return true if parsing, calculation of the masses and validation
     were successful, false otherwise.
 
     \sa validate().
     \sa formatXmlMnmElement(int offset, const QString &indent).
   */
-  bool 
+  bool
   Monomer::renderXmlMnmElement(const QDomElement &element, int version)
   {
     // For the time being the version is not necessary here. As of
@@ -804,9 +804,9 @@ namespace massXpert
 
     if (version == 1)
       ;
-  
+
     QDomElement child;
- 
+
     /* In a polymer chemistry definition, the xml node we are in is
      * structured this way:
      *
@@ -816,13 +816,13 @@ namespace massXpert
      *   <formula>C2H3N1O1</formula>
      * </mnm>
      *
-     * And the element parameter points to the 
+     * And the element parameter points to the
      *
      * <mnm> element tag:
      *  ^
      *  |
      *  +----- here we are right now.
-     * 
+     *
      * Which means that element.tagName() == "mnm" and that we'll have
      * to go one step down to the first child of the current node in
      * order to get to the <name> element.
@@ -833,40 +833,40 @@ namespace massXpert
       return false;
 
     child = element.firstChildElement("name");
-  
+
     if (child.isNull())
       return false;
-  
+
     m_name = child.text();
-  
+
     child = child.nextSiblingElement("code");
-  
+
     if (child.isNull())
       return false;
-  
+
     m_code = child.text();
-    
+
     child = child.nextSiblingElement("formula");
-  
+
     if (child.isNull())
       return false;
-  
+
     if (!Formula::renderXmlFormulaElement(child))
       return false;
 
     if (!calculateMasses())
       {
-	qDebug() << __FILE__ << __LINE__ 
-		  << "Failed to calculate masses for monomer" 
-		  << m_name;
+        qDebug() << __FILE__ << __LINE__
+                 << "Failed to calculate masses for monomer"
+                 << m_name;
 
-	return false;
+        return false;
       }
-  
+
     if (!validate())
       return false;
-  
-      
+
+
     return true;
   }
 
@@ -876,14 +876,14 @@ namespace massXpert
     polymer chemistry definition file. The typical monomer element that
     is generated in this function looks like this:
 
-    \verbatim 
+    \verbatim
     <mnm>
     <name>Valine</name>
     <code>V</code>
     <formula>C5H9NO</formula>
     </mnm>
-    \endverbatim  
-  
+    \endverbatim
+
     \param offset times the \p indent string must be used as a lead in the
     formatting of elements.
 
@@ -901,31 +901,31 @@ namespace massXpert
   {
     int newOffset;
     int iter = 0;
-  
+
     QString lead("");
     QString *string = new QString();
-  
+
     // Prepare the lead.
-    newOffset = offset;  
+    newOffset = offset;
     while(iter < newOffset)
       {
-	lead += indent;
-	++iter;
+        lead += indent;
+        ++iter;
       }
 
     *string += QString("%1<mnm>\n")
       .arg(lead);
-  
+
     // Prepare the lead.
     ++newOffset;
     lead.clear();
     iter = 0;
     while(iter < newOffset)
       {
-	lead += indent;
-	++iter;
+        lead += indent;
+        ++iter;
       }
-  
+
     // Continue with indented elements.
 
     *string += QString("%1<name>%2</name>\n")
@@ -935,24 +935,24 @@ namespace massXpert
     *string += QString("%1<code>%2</code>\n")
       .arg(lead)
       .arg(m_code);
-    
+
     *string += QString("%1<formula>%2</formula>\n")
       .arg(lead)
       .arg(m_formula);
-  
+
     // Prepare the lead for the closing element.
     --newOffset;
     lead.clear();
     iter = 0;
     while(iter < newOffset)
       {
-	lead += indent;
-	++iter;
+        lead += indent;
+        ++iter;
       }
 
     *string += QString("%1</mnm>\n")
       .arg(lead);
-  
+
     return string;
   }
 
@@ -967,14 +967,14 @@ namespace massXpert
     If properties are available for the monomer element, these are
     parsed and the resulting property objects are set to \p this
     monomer.
-  
+
     \param element XML element to be parsed and rendered.
-  
+
     \return true if parsing was successful, false otherwise.
 
     \sa formatXmlMonomerElement(int offset, const QString &indent).
   */
-  bool 
+  bool
   Monomer::renderXmlMonomerElement(const QDomElement &element, int version)
   {
     // We have to check for the version since
@@ -982,21 +982,21 @@ namespace massXpert
 
     if (version >= 5)
       return renderXmlMonomerElementV2(element, version);
-  
+
     QDomElement child;
     QDomElement indentedChild;
-  
+
 
     if (element.tagName() != "monomer")
       return false;
 
     child = element.firstChildElement("code");
-  
+
     if (child.isNull())
       return false;
-  
+
     m_code = child.text();
-  
+
     Monomer other(mp_polChemDef, "NOT_SET");
     const QList<Monomer*> &refList = mp_polChemDef->monomerList();
 
@@ -1004,75 +1004,75 @@ namespace massXpert
     index = isCodeInList(m_code, refList, &other);
     if (index == -1)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
-  
+
     // Mold this monomer.
     mold(other);
-  
+
     // And now we have to manage the prop objects.
     child = child.nextSiblingElement();
 
     while(!child.isNull())
       {
-	if(child.tagName() != "prop")
-	  return false;
-      
-	indentedChild = child.firstChildElement();
-	if(indentedChild.tagName() != "name")
-	  return false;
-      
-	Prop *prop = 
-	  static_cast<Prop *>(propAllocator(indentedChild.text(),
-					      mp_polChemDef));
-      
-	if(prop)
-	  {
-	    if (!prop->renderXmlElement(child, version))
-	      {
-		delete prop;
-		return false;
-	      }
+        if(child.tagName() != "prop")
+          return false;
 
-	    // At this point, the modification lies inside the prop
-	    // object.
-	    Modif *modif =
-	      new Modif(*static_cast<Modif *>(prop->data()));
-	  
-	    // OK, at this point we can add the new modif to the list of
-	    // modifs.
-	    if (!mpa_modifList)
-	      mpa_modifList = new QList<Modif *>();
-	  
-	    mpa_modifList->append(modif);
+        indentedChild = child.firstChildElement();
+        if(indentedChild.tagName() != "name")
+          return false;
 
-	    delete prop;
-	  }
-	else
-	  return false;
-      
-	child = child.nextSiblingElement();
+        Prop *prop =
+          static_cast<Prop *>(propAllocator(indentedChild.text(),
+                                            mp_polChemDef));
+
+        if(prop)
+          {
+            if (!prop->renderXmlElement(child, version))
+              {
+                delete prop;
+                return false;
+              }
+
+            // At this point, the modification lies inside the prop
+            // object.
+            Modif *modif =
+              new Modif(*static_cast<Modif *>(prop->data()));
+
+            // OK, at this point we can add the new modif to the list of
+            // modifs.
+            if (!mpa_modifList)
+              mpa_modifList = new QList<Modif *>();
+
+            mpa_modifList->append(modif);
+
+            delete prop;
+          }
+        else
+          return false;
+
+        child = child.nextSiblingElement();
       }
-  
+
     return true;
   }
 
 
-  bool 
+  bool
   Monomer::renderXmlMonomerElementV2(const QDomElement &element, int version)
   {
     QDomElement child;
     QDomElement indentedChild;
-  
+
 
     if (element.tagName() != "monomer")
       return false;
 
     child = element.firstChildElement("code");
-  
+
     if (child.isNull())
       return false;
-  
+
     m_code = child.text();
-  
+
     Monomer other(mp_polChemDef, "NOT_SET");
     const QList<Monomer*> &refList = mp_polChemDef->monomerList();
 
@@ -1080,58 +1080,58 @@ namespace massXpert
     index = isCodeInList(m_code, refList, &other);
     if (index == -1)
       qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
-  
+
     // Mold this monomer.
     mold(other);
-  
+
     // And now we have to manage the prop objects.
     child = child.nextSiblingElement();
 
     while(!child.isNull())
       {
-	if(child.tagName() != "mdf")
-	  return false;
-      
-	// Allocate the modification that will be set to the monomer
-	// element.
+        if(child.tagName() != "mdf")
+          return false;
 
-	Modif *modif = new Modif(mp_polChemDef, "NOT_SET", "NOT_SET");
+        // Allocate the modification that will be set to the monomer
+        // element.
 
-	if(!modif->renderXmlMdfElementV2(child))
-	  {
-	    delete modif;
-	    return false;
-	  }
+        Modif *modif = new Modif(mp_polChemDef, "NOT_SET", "NOT_SET");
 
-	if(!modif->calculateMasses())
-	  {
-	    qDebug() << __FILE__ << __LINE__ 
-		      << "Failed to calculate masses for modification"
-		      << modif->name();
-	  
-	    delete modif;
-	    return false;
-	  }
+        if(!modif->renderXmlMdfElementV2(child))
+          {
+            delete modif;
+            return false;
+          }
 
-	// The validation will take care of checking that the <targets>
-	// element did have correct text inside.
-      
-	if(!modif->validate())
-	  {
-	    delete modif;
-	    return false;
-	  }
-	
-	// OK, at this point we can add the new modif to the list of
-	// modifs.
-	if(!mpa_modifList)
-	  mpa_modifList = new QList<Modif *>();
-      
-	mpa_modifList->append(modif);
-      
-	child = child.nextSiblingElement();
+        if(!modif->calculateMasses())
+          {
+            qDebug() << __FILE__ << __LINE__
+                     << "Failed to calculate masses for modification"
+                     << modif->name();
+
+            delete modif;
+            return false;
+          }
+
+        // The validation will take care of checking that the <targets>
+        // element did have correct text inside.
+
+        if(!modif->validate())
+          {
+            delete modif;
+            return false;
+          }
+
+        // OK, at this point we can add the new modif to the list of
+        // modifs.
+        if(!mpa_modifList)
+          mpa_modifList = new QList<Modif *>();
+
+        mpa_modifList->append(modif);
+
+        child = child.nextSiblingElement();
       }
-  
+
     return true;
   }
 
@@ -1141,7 +1141,7 @@ namespace massXpert
     polymer sequence file. The typical monomer element that is generated
     in this function looks like this:
 
-    \verbatim 
+    \verbatim
     <monomer>
     <code>S</code>
     <prop>
@@ -1153,8 +1153,8 @@ namespace massXpert
     <data>Phosphorylation is only partial</data>
     </prop>
     </monomer>
-    \endverbatim  
-  
+    \endverbatim
+
     \param offset times the \p indent string must be used as a lead in the
     formatting of elements.
 
@@ -1172,80 +1172,80 @@ namespace massXpert
   {
     int newOffset;
     int iter = 0;
-  
+
     QString lead("");
     QString *string = new QString();
-  
+
     // Prepare the lead.
-    newOffset = offset;  
+    newOffset = offset;
     while(iter < newOffset)
       {
-	lead += indent;
-	++iter;
+        lead += indent;
+        ++iter;
       }
 
     *string += QString("%1<monomer>\n")
       .arg(lead);
-  
+
     // Prepare the lead.
     ++newOffset;
     lead.clear();
     iter = 0;
     while(iter < newOffset)
       {
-	lead += indent;
-	++iter;
+        lead += indent;
+        ++iter;
       }
-  
+
     // Continue with indented elements.
 
     *string += QString("%1<code>%2</code>\n")
       .arg(lead)
       .arg(m_code);
-    
+
     // The monomer may have any number of modif objects, which we have
     // to document here.
     if (mpa_modifList && mpa_modifList->size())
       {
-	for(iter = 0 ; iter < mpa_modifList->size(); ++iter)
-	  {
-	    Modif *modif = mpa_modifList->at(iter);
-	  
-	    QString *modifString = modif->formatXmlMdfElement(newOffset);
-	    Q_ASSERT(modifString);
-	  
-	    *string += *modifString;
-	    delete modifString;
-	  }
+        for(iter = 0 ; iter < mpa_modifList->size(); ++iter)
+          {
+            Modif *modif = mpa_modifList->at(iter);
+
+            QString *modifString = modif->formatXmlMdfElement(newOffset);
+            Q_ASSERT(modifString);
+
+            *string += *modifString;
+            delete modifString;
+          }
       }
-  
+
     // Prepare the lead for the closing element.
     --newOffset;
     lead.clear();
     iter = 0;
     while(iter < newOffset)
       {
-	lead += indent;
-	++iter;
+        lead += indent;
+        ++iter;
       }
 
     *string += QString("%1</monomer>\n")
       .arg(lead);
-  
+
     return string;
   }
 
 
   //! Creates a string
-  /*! 
-  
+  /*!
+
    */
-  void 
+  void
   Monomer::debugPutStdErr() const
   {
-    qDebug() << __FILE__ << __LINE__ 
-	      << m_name.toAscii() << m_code.toAscii() 
-	      << m_formula.toAscii();
+    qDebug() << __FILE__ << __LINE__
+             << m_name << m_code
+             << m_formula;
   }
 
 } // namespace massXpert
