@@ -69,14 +69,18 @@ namespace massXpert
     \param isIonized Indicates if the oligomer should be considered
     ionized.
   */
-  Oligomer::Oligomer(Polymer *polymer , const QString &name, 
+  Oligomer::Oligomer(Polymer *polymer ,
+                     const QString &name,
+                     const QString &description,
                      const Ponderable &ponderable,
                      const IonizeRule &ionizeRule,
                      const CalcOptions & calcOptions,
                      bool isIonized,
                      int startIndex, int endIndex)
     : Ionizable(polymer->polChemDef(), name, ponderable, 
-                ionizeRule, isIonized), mp_polymer(polymer),
+                ionizeRule, isIonized),
+      mp_polymer(polymer),
+      m_description(description),
       m_calcOptions(calcOptions)
   {
     setStartEndIndices(startIndex, endIndex);
@@ -112,19 +116,23 @@ namespace massXpert
     \param isIonized Indicates if the oligomer should be considered
     ionized.
   */
-  Oligomer::Oligomer(const PolChemDef *polChemDef, const QString &name, 
+  Oligomer::Oligomer(const PolChemDef *polChemDef,
+                     const QString &name,
+                     const QString &description,
                      const Ponderable &ponderable,
                      const IonizeRule &ionizeRule,
                      const CalcOptions &calcOptions,
                      bool isIonized,
                      int startIndex, int endIndex)
     : Ionizable(polChemDef, name, ponderable, ionizeRule, isIonized), 
-      mp_polymer(0), m_calcOptions(calcOptions)
+      mp_polymer(0),
+      m_description(description),
+      m_calcOptions(calcOptions)
   {
     setStartEndIndices(startIndex, endIndex);
-    if (startIndex < 0)
-      qDebug() << __FILE__ << __LINE__
-               << "Construct with startIndex:" << startIndex;
+    // if (startIndex < 0)
+    //   qDebug() << __FILE__ << __LINE__
+    //            << "Construct with startIndex:" << startIndex;
   }
   
 
@@ -148,12 +156,16 @@ namespace massXpert
     polymer sequence(note that this index is stored in the very first
     Coordinates item in the CoordinateList).
   */
-  Oligomer::Oligomer(Polymer *polymer, const QString &name, 
+  Oligomer::Oligomer(Polymer *polymer,
+                     const QString &name,
+                     const QString &description,
                      const Ponderable &ponderable,
                      int startIndex, int endIndex,
                      const CalcOptions &calcOptions)
     : Ionizable(polymer->polChemDef(), name, ponderable), 
-      mp_polymer(polymer), m_calcOptions(calcOptions)
+      mp_polymer(polymer),
+      m_description(description),
+      m_calcOptions(calcOptions)
   {
     setStartEndIndices(startIndex, endIndex);
     if (startIndex < 0)
@@ -186,11 +198,15 @@ namespace massXpert
     polymer sequence(note that this index is stored in the very first
     Coordinates item in the CoordinateList).
   */
-  Oligomer::Oligomer(const PolChemDef *polChemDef, const QString &name, 
+  Oligomer::Oligomer(const PolChemDef *polChemDef,
+                     const QString &name,
+                     const QString &description,
                      const Ponderable &ponderable,
                      const CalcOptions &calcOptions,
                      int startIndex, int endIndex)
-    : Ionizable(polChemDef, name, ponderable), mp_polymer(0), 
+    : Ionizable(polChemDef, name, ponderable),
+      mp_polymer(0), 
+      m_description(description),
       m_calcOptions(calcOptions)
   {
     setStartEndIndices(startIndex, endIndex);
@@ -203,7 +219,9 @@ namespace massXpert
   Oligomer::Oligomer(const Ionizable& ionizable,
                      const CalcOptions &calcOptions,
                      int startIndex, int endIndex)
-    : Ionizable(ionizable), mp_polymer(0), 
+    : Ionizable(ionizable),
+      mp_polymer(0),
+      m_description("NOT_SET"),
       m_calcOptions(calcOptions)
   {
     setStartEndIndices(startIndex, endIndex);
@@ -231,12 +249,16 @@ namespace massXpert
 
     \param avg Average mass.
   */
-  Oligomer::Oligomer(Polymer *polymer , const QString &name,
+  Oligomer::Oligomer(Polymer *polymer ,
+                     const QString &name,
+                     const QString &description,
                      double mono, double avg,
                      int startIndex, int endIndex, 
                      const CalcOptions &calcOptions)
     : Ionizable(mp_polymer->polChemDef(), name, Ponderable(mono, avg)),
-      mp_polymer(polymer), m_calcOptions(calcOptions)
+      mp_polymer(polymer),
+      m_description(description),
+      m_calcOptions(calcOptions)
   {
     setStartEndIndices(startIndex, endIndex);
     if (startIndex < 0)
@@ -267,12 +289,16 @@ namespace massXpert
 
     \param avg Average mass.
   */
-  Oligomer::Oligomer(const PolChemDef *polChemDef, const QString &name, 
+  Oligomer::Oligomer(const PolChemDef *polChemDef,
+                     const QString &name,
+                     const QString &description,
                      const CalcOptions &calcOptions,
                      double mono, double avg,
                      int startIndex, int endIndex)
     : Ionizable(polChemDef, name, Ponderable(mono, avg)),
-      mp_polymer(0),m_calcOptions(calcOptions)
+      mp_polymer(0),
+      m_description(description),
+      m_calcOptions(calcOptions)
   {
     setStartEndIndices(startIndex, endIndex);
   }
@@ -286,7 +312,9 @@ namespace massXpert
   */
   Oligomer::Oligomer(const Oligomer &other)
     : CoordinateList(other), Ionizable(other), PropListHolder(other),
-      mp_polymer(other.mp_polymer), m_calcOptions(other.m_calcOptions)
+      mp_polymer(other.mp_polymer),
+      m_description(other.m_description),
+      m_calcOptions(other.m_calcOptions)
   {
   }
   
@@ -407,7 +435,21 @@ namespace massXpert
     return coordinates->end();
   }
 
+  
+  void
+  Oligomer::setDescription(const QString &description)
+  {
+    m_description = description;
+  }
 
+  
+  QString
+  Oligomer::description() const
+  {
+    return m_description;
+  }
+  
+  
   int 
   Oligomer::appendCoordinates(CoordinateList *list)
   {
