@@ -57,6 +57,11 @@ namespace massXpert
   {
     m_ph = 7;
     m_pi = 7;
+    m_positiveCharges = 0;
+    m_negativeCharges = 0;
+    
+    mp_aborted = 0;
+    mp_progress = 0;
   }
 
 
