@@ -63,8 +63,9 @@ namespace massXpert
 {
 
   //! The PolChemDef class provides a polymer chemistry definition.
-  /*! A polymer chemistry definition allows to characterize in a fine
-    manner the chemistry of a polymer. That means that it should contain:
+  /*! A polymer chemistry definition allows one to characterize in a
+    fine manner the chemistry of a polymer. That means that it should
+    contain:
 
     -  a list of atoms; 
 
