@@ -284,6 +284,161 @@ namespace massXpert
   }
 
 
+  // Only put in the indexList, the indices of the monomers that are
+  // involved in cross-links fully contained in the
+  // [startIndex--endIndex] region. However, if partical cross-links
+  // are encountered, set the partials boolean value to true.  Return
+  // true if at least one fully encompassed cross-link is found in the
+  // range.
+  bool
+  Polymer::crossLinkedMonomerIndexList(int startIndex, 
+                                       int endIndex, 
+                                       QList<int> *indexList,
+                                       int *partials)
+  {
+    if(!indexList)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+    // We are asked to return a list of all the indices of the
+    // monomers involved in cross-links that link any monomer in the
+    // region delimited by startIndex and endIndex.
+    
+    bool oneFound = false;
+    
+    // Iterate in the list of cross-links set to *this polymer.  For
+    // each iterated cross-link, check if it is fully encompasse by
+    // the region delimited by [startIndex--endIndex]. If so, get the
+    // indices of the monomers involved in that cross-link and append
+    // these (no duplicates) to the indexList passed as param to the
+    // function.
+    for(int jter = 0; jter < m_crossLinkList.size(); ++jter)
+      {
+        CrossLink *crossLink = m_crossLinkList.at(jter);
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "Cross-link:" << crossLink;
+        
+        int ret = crossLink->encompassedBy(startIndex, endIndex);
+
+        if(ret == MXP_CROSS_LINK_ENCOMPASSED_FULL)
+          {
+            // qDebug() << __FILE__ << __LINE__
+            //          << "Cross-link:" << crossLink
+            //          << "is encompassed by region:"
+            //          << startIndex << "-" << endIndex;
+                        
+            QList<int> localIndexList;
+            
+            crossLink->monomerIndexList(&localIndexList);
+
+            // qDebug() << __FILE__ << __LINE__
+            //          << "Index list:" << localIndexList;
+            
+            // Avoid duplicating indices in the target index
+            // list. This will have the excellent side effect of
+            // condensating into one single region a number of
+            // contained cross-linked regions. For example, from the
+            // Kunitz inhibitor, there are the following cross-links:
+
+            // 90 -- 187
+            // 230 -- 280
+            // 239 -- 263
+            // 255 -- 276
+            // 286 -- 336
+            // 295 -- 319
+            // 311 -- 332
+
+            // Thanks to our strategy below, the cross-links 
+            // 230 -- 280
+            // 239 -- 263
+            // 255 -- 276
+            // become contained in one single region:
+            // 230--276.
+
+            // Same for the cross-links
+            // 286 -- 336
+            // 295 -- 319
+            // 311 -- 332
+            // Which become contained in 286--336
+
+            for(int iter = 0, size = localIndexList.size();
+                iter < size; ++iter)
+              {
+                int index = localIndexList.at(iter);
+                
+                if(!indexList->contains(index))
+                  indexList->append(index);
+              }
+                                    
+            oneFound = true;
+          }
+        else if(ret == MXP_CROSS_LINK_ENCOMPASSED_PARTIAL)
+          {
+            if(partials)
+              ++(*partials);
+          }
+      }
+    
+    return oneFound;
+  }
+  
+
+  // We want to get a list of cross-links that are encompassed by the
+  // given region, delimited by startIndex and endIndex. Each found
+  // cross-link has its pointer added to the list. Of course the
+  // caller cannot destroy these cross-links because they would be
+  // destroyed in the sequence ! We only list the cross-links that are
+  // FULLY encompassed, but we report the presence of partially
+  // encompassed cross-links by setting  *partial to true.
+  bool
+  Polymer::crossLinkList(int startIndex, 
+                         int endIndex, 
+                         QList<CrossLink *> *list,
+                         int *partials)
+  {
+    if(!list)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+    // We are asked to return a list of all the cross-links that are
+    // fully encompassed by the [startIndex--endIndex] region.
+
+    bool oneFound = false;
+    
+    // Iterate in the list of cross-links set to *this polymer.  For
+    // each iterated cross-link, check if it is fully encompassed by
+    // the [startIndex--endIndex] region. If so simply add it to the
+    // list of cross-links.
+    for(int jter = 0; jter < m_crossLinkList.size(); ++jter)
+      {
+        CrossLink *crossLink = m_crossLinkList.at(jter);
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "Cross-link:" << crossLink;
+        
+        int ret = crossLink->encompassedBy(startIndex, endIndex);
+
+        if(ret == MXP_CROSS_LINK_ENCOMPASSED_FULL)
+          {
+            // qDebug() << __FILE__ << __LINE__
+            //          << "Cross-link:" << crossLink
+            //          << "is encompassed by region:"
+            //          << startIndex << "-" << endIndex;
+            list->append(crossLink);
+                                                
+            oneFound = true;
+          }
+        else if(ret == MXP_CROSS_LINK_ENCOMPASSED_PARTIAL)
+          {
+            if(partials)
+              ++(*partials);
+          }
+      }
+    
+    return oneFound;
+  }
+  
+
+
   bool 
   Polymer::prepareMonomerRemoval(Monomer *monomer)
   {
@@ -369,7 +524,7 @@ namespace massXpert
 
   bool 
   Polymer::calculateMasses(Polymer *polymer, 
-			    const CalcOptions &calcOptions,
+                           const CalcOptions &calcOptions,
 			    double *mono, double *avg, bool reset)
   {
     Q_ASSERT(polymer);
@@ -782,10 +937,277 @@ namespace massXpert
   }
 
 
+  QString 
+  Polymer::elementalComposition(const IonizeRule &ionizeRule,
+                                const CoordinateList &coordinateList,
+                                const CalcOptions &calcOptions)
+  {
+    Formula formula;
+    const QList <Atom *> &atomRefList = mp_polChemDef->atomList(); 
+
+    // Iterate in all the oligomers that are encompassed in the
+    // selection.
+    
+    for (int iter = 0; iter < coordinateList.size(); ++iter)
+      {
+	// New coordinates instance we are iterating into.
+	Coordinates *coordinates = coordinateList.at(iter);
+	
+	for(int jter = coordinates->start() ; 
+            jter < coordinates->end() + 1; ++jter)
+	  {
+	    const Monomer *iterMonomer = at(jter);
+	    Q_ASSERT(iterMonomer);
+      
+	    // Set the formula of the new monomer in the same formula
+	    // instance.
+	    formula.setFormula(iterMonomer->formula());
+
+	    // Incrementally account for the new formula in the same
+	    // atomcount list in the formula.
+	    if (formula.accountAtoms(atomRefList, 1) == false)
+              qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+	    if (calcOptions.monomerEntities() & 
+                MXT_MONOMER_CHEMENT_MODIF &&
+                iterMonomer->isModified())
+	      {
+                for (int jter = 0; 
+                     jter < iterMonomer->modifList()->size();
+                     ++jter)
+                  {
+                    Modif *modif = iterMonomer->modifList()->at(jter);
+                    
+                    formula.setFormula(modif->formula());
+                    
+                    // Incrementally account for the new formula in the same
+                    // atomcount list in the formula.
+                    if(formula.accountAtoms(atomRefList, 1) == false)
+                      qFatal("Fatal error at %s@%d. "
+                             "Aborting.",__FILE__, __LINE__);    
+                  }
+	      }
+	  }
+	// End of for (int jter = m_startIndex ; jter < m_endIndex + 1;
+	// ++jter)
+      }
+    
+    //     qDebug() << __FILE__ << __LINE__
+    // 	      << "Formula after accounting for all the residual chains:"
+    // 	      << formula.elementalComposition();
+    
+    // We now have to account for the left/right cappings. However,
+    // when there are multiple region selections(that is multiple
+    // Coordinate elements in the calcOptions.coordinateList()) it is
+    // necessary to know if the user wants each of these Coordinates
+    // to be considered real oligomers(each one with its left/right
+    // caps) or as residual chains. Thus there are two cases:
+
+    // 1. Each Coordinates item should be considered an oligomer
+    //(SelectionType is SELECTION_TYPE_OLIGOMERS), thus for each item
+    // the left and right caps should be accounted for. This is
+    // typically the case when the user selects multiple regions to
+    // compute the mass of cross-linked oligomers.
+
+    // 2. Each Coordinates item should be considered a residual chain
+    //(SelectionType is SELECTION_TYPE_RESIDUAL_CHAINS), thus only
+    // one item should see its left and right caps accounted for. This
+    // is typically the case when the user selects multiple regions
+    // like it would select repeated sequence elements in a polymer
+    // sequence: all the regions selected are treated as a single
+    // oligomer.
+
+    // Holds the number of times the chemical entities are to be
+    // accounted for.
+    int times = 0;
+    
+    if (calcOptions.selectionType() == SELECTION_TYPE_RESIDUAL_CHAINS)
+      {
+	times = 1;
+        // qDebug() << __FILE__ << __LINE__
+        //          << "SELECTION_TYPE_RESIDUAL_CHAINS ; times:" << times;
+      }
+    else
+      {
+	times = calcOptions.coordinateList().size();
+
+        // qDebug() << __FILE__ << __LINE__
+        //          << "SELECTION_TYPE_OLIGOMERS ; times:" << times;
+      }
+    
+    // Account for the left and right cap masses, if so required.
+
+    if (calcOptions.capping() & MXT_CAP_LEFT)
+      {
+	formula.setFormula(mp_polChemDef->leftCap());
+
+	// Incrementally account for the new formula in the same
+	// atomcount list in the formula.
+	if(formula.accountAtoms(atomRefList, times) == false)
+          qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+	
+        // qDebug() << __FILE__ << __LINE__
+        //          << "Formula after accounting left cap:"
+        //          << formula.elementalComposition();
+      }
+    
+    if (calcOptions.capping() & MXT_CAP_RIGHT)
+      {
+	formula.setFormula(mp_polChemDef->rightCap());
+      
+	// Incrementally account for the new formula in the same
+	// atomcount list in the formula.
+	if(formula.accountAtoms(atomRefList, times) == false)
+          qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+	
+        // qDebug() << __FILE__ << __LINE__
+        //          << "Formula after accounting right cap:"
+        //          << formula.elementalComposition();
+      }
+    
+    // Account for the left and right modification masses, if so
+    // required and the region(s) require(s) it: we have to make it
+    // clear if the selection encompasses indices 0(left end) and/or
+    // polymerSize-1(right end).
+    
+    if (calcOptions.polymerEntities() & 
+	MXT_POLYMER_CHEMENT_LEFT_END_MODIF)
+      {
+	if(coordinateList.encompassIndex(0))
+	  {
+	    Modif modif =  leftEndModif();
+      
+	    formula.setFormula(modif.formula());
+
+	    // qDebug() << __FILE__ << __LINE__
+            //          << "Accounting for left end modif:"
+            //          << modif.name();
+	    
+	    // Incrementally account for the new formula in the same
+	    // atomcount list in the formula.
+	    if (formula.accountAtoms(atomRefList, 1) == false)
+              qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+            // qDebug() << __FILE__ << __LINE__
+            //          << "Formula after accounting left end modif:"
+            //          << formula.elementalComposition();
+	  }
+      }
+    
+    if (calcOptions.polymerEntities() & 
+	MXT_POLYMER_CHEMENT_RIGHT_END_MODIF)
+      {
+	if(coordinateList.encompassIndex(size() - 1))
+	  {
+	    Modif modif =  rightEndModif();
+      
+	    formula.setFormula(modif.formula());
+
+            // 	    qDebug() << __FILE__ << __LINE__
+            // 		      << "Accounting for right end modif:"
+            // 		      << modif.name();
+	    
+	    // Incrementally account for the new formula in the same
+	    // atomcount list in the formula.
+	    if (formula.accountAtoms(atomRefList, 1) == false)
+              qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+            // qDebug() << __FILE__ << __LINE__
+            //          << "Formula after accounting right end modif:"
+            //          << formula.elementalComposition();
+	  }
+      }
+
+    // At this point we should not forget if the user asks to take into
+    // account the cross-links... However, BE CAREFUL that cross-links
+    // can only be taken into account if all the partners of a given
+    // cross-link are actually encompassed into the selection.
+
+    if (calcOptions.monomerEntities() & MXT_MONOMER_CHEMENT_CROSS_LINK)
+      {
+      
+	for(int iter = 0; iter < crossLinkList().size(); ++iter)
+	  {
+	    CrossLink *crossLink = crossLinkList().at(iter);
+	  
+	    if (crossLink->encompassedBy(coordinateList)
+		== MXP_CROSS_LINK_ENCOMPASSED_FULL)
+	      {
+		// The crossLink is fully encompassed by our monomer
+		// stretch, so we should take it into account.
+	      
+                // qDebug() << __FILE__ << __LINE__
+                //          << "Accounting for fully encompassed cross-link:"
+                //          << crossLink->name();
+		
+		if(!crossLink->formula().isEmpty())
+		  {
+		    formula.setFormula(crossLink->formula());
+		  
+		    // qDebug() << __FILE__ << __LINE__ 
+                    //          << "Cross-link formula:" << crossLink->formula();
+                    
+		    // Incrementally account for the new formula in the same
+		    // atomcount list in the formula.
+		    if (formula.accountAtoms(atomRefList, 1) == false)
+                      qFatal("Fatal error at %s@%d. "
+                             "Aborting.",__FILE__, __LINE__);
+		  }
+	      
+		// And now each modification that belongs to the
+		// crosslinker.
+	      
+		for(int jter = 0; 
+                    jter < crossLink->modifList().size(); 
+                    ++jter)
+		  {
+		    QString iterFormulaString = 
+		      crossLink->modifList().at(jter)->formula();
+		  
+                    // qDebug() << __FILE__ << __LINE__ 
+                    //          << "Cross-link's modif formula:" 
+                    //          << iterFormulaString;
+                    
+		    formula.setFormula(iterFormulaString);
+                    
+		    // Incrementally account for the new formula in the same
+		    // atomcount list in the formula.
+		    if (formula.accountAtoms(atomRefList, 1) == false)
+                      qFatal("Fatal error at %s@%d. "
+                             "Aborting.",__FILE__, __LINE__);
+		  }
+	      }
+	    // End of 
+	    // if (ret == MXP_CROSS_LINK_ENCOMPASSED_FULL)
+	  }
+	// End of
+	// for (int iter = 0; iter < crossLinkList->size(); ++iter)
+      }
+    // End of
+    // if (calcOptions.monomerEntities() & MXT_MONOMER_CHEMENT_CROSS_LINK)
+  
+  
+    // The ionization rule. Do not forget to take into account the
+    // level!
+    formula.setFormula(ionizeRule.formula());
+  
+    // Incrementally account for the new formula in the same
+    // atomcount list in the formula.
+    if (formula.accountAtoms(atomRefList, ionizeRule.level()) == false)
+      qFatal("Fatal error at %s@%d. Aborting.",__FILE__, __LINE__);
+
+    // qDebug() << __FILE__ << __LINE__
+    //          << "Formula after accounting ionization: "
+    //          << formula.elementalComposition();
+    
+    return formula.elementalComposition();
+  }
+  
+
 
   //! Parses an XML element holding a stretch of monomer codes.
   /*! Parses the XML element passed as argument and get its text data
-   (this is called XML rendering). The string(a stretch of monomer
+    (this is called XML rendering). The string(a stretch of monomer
     codes) is then converted into a list of dynamically allocated
     Monomer instances. The monomers already in the list are not
     removed, as this function might be called any number of times during
@@ -1796,16 +2218,16 @@ namespace massXpert
   Polymer::debugPutStdErr()
   {
     qDebug() << __FILE__ << __LINE__;
-    qDebug() << m_name.toAscii() << m_code.toAscii();
-    qDebug() << mp_polChemDef->name().toAscii();
-    qDebug() << m_author.toAscii() << m_filePath.toAscii();
-    qDebug() << m_leftEndModif.name().toAscii() 
-	      << m_rightEndModif.name().toAscii();
+    qDebug() << m_name << m_code;
+    qDebug() << mp_polChemDef->name();
+    qDebug() << m_author << m_filePath;
+    qDebug() << m_leftEndModif.name() 
+	      << m_rightEndModif.name();
 
 
     for (int iter = 0 ; iter < m_monomerList.size(); ++iter)
       {
-	qDebug() << m_monomerList.at(iter)->code().toAscii();
+	qDebug() << m_monomerList.at(iter)->code();
       }
   }
 
