@@ -136,7 +136,9 @@ namespace massXpert
 
     const CrossLinkList &crossLinkList() const;
     CrossLinkList *crossLinkListPtr();
-
+    bool crossLinkedMonomerIndexList(int, int, QList<int> *, int *);
+    bool crossLinkList(int, int, QList<CrossLink *> *, int *);
+    
     virtual bool prepareMonomerRemoval(Monomer *);
     virtual bool removeMonomerAt(int);
   
@@ -169,6 +171,16 @@ namespace massXpert
     /////////////////////////////
     // MASS CALCULATION FUNCTIONS
 
+    // ELEMENTAL CALCULATION FUNCTION
+    /////////////////////////////////
+    
+    QString elementalComposition(const IonizeRule &,
+                                 const CoordinateList &,
+                                 const CalcOptions &);
+    
+    /////////////////////////////////
+    // ELEMENTAL CALCULATION FUNCTION
+    
     bool renderXmlCodesElement(const QDomElement &element);
 
     static QString xmlPolymerFileGetPolChemDefName(const QString &filePath);
